from design_bench.datasets.discrete_dataset import DiscreteDataset
from design_bench.disk_resource import DiskResource, SERVER_URL


CHEMBL_FILES = ['chembl-GI50-CHEMBL1963844/chembl-x-0.npy', 'chembl-GI50-CHEMBL1963854/chembl-x-0.npy', 'chembl-GI50-CHEMBL1963860/chembl-x-0.npy', 'chembl-GI50-CHEMBL1963866/chembl-x-0.npy', 'chembl-GI50-CHEMBL1963868/chembl-x-0.npy', 'chembl-GI50-CHEMBL1963874/chembl-x-0.npy', 'chembl-GI50-CHEMBL1963876/chembl-x-0.npy', 'chembl-GI50-CHEMBL1963880/chembl-x-0.npy', 'chembl-GI50-CHEMBL1963882/chembl-x-0.npy', 'chembl-GI50-CHEMBL1963885/chembl-x-0.npy', 'chembl-GI50-CHEMBL1963895/chembl-x-0.npy', 'chembl-GI50-CHEMBL1963900/chembl-x-0.npy', 'chembl-GI50-CHEMBL1963901/chembl-x-0.npy', 'chembl-GI50-CHEMBL1963903/chembl-x-0.npy', 'chembl-GI50-CHEMBL1963911/chembl-x-0.npy', 'chembl-GI50-CHEMBL1963921/chembl-x-0.npy', 'chembl-GI50-CHEMBL1963922/chembl-x-0.npy', 'chembl-GI50-CHEMBL1963929/chembl-x-0.npy', 'chembl-GI50-CHEMBL1963945/chembl-x-0.npy', 'chembl-GI50-CHEMBL1963953/chembl-x-0.npy', 'chembl-GI50-CHEMBL1963960/chembl-x-0.npy', 'chembl-GI50-CHEMBL1963961/chembl-x-0.npy', 'chembl-GI50-CHEMBL1963976/chembl-x-0.npy', 'chembl-GI50-CHEMBL1963981/chembl-x-0.npy', 'chembl-GI50-CHEMBL1963985/chembl-x-0.npy', 'chembl-GI50-CHEMBL1963989/chembl-x-0.npy', 'chembl-GI50-CHEMBL1963990/chembl-x-0.npy', 'chembl-GI50-CHEMBL1963991/chembl-x-0.npy', 'chembl-GI50-CHEMBL1963994/chembl-x-0.npy', 'chembl-GI50-CHEMBL1964004/chembl-x-0.npy', 'chembl-GI50-CHEMBL1964006/chembl-x-0.npy', 'chembl-GI50-CHEMBL1964007/chembl-x-0.npy', 'chembl-GI50-CHEMBL1964009/chembl-x-0.npy', 'chembl-GI50-CHEMBL1964012/chembl-x-0.npy', 'chembl-GI50-CHEMBL1964017/chembl-x-0.npy', 'chembl-GI50-CHEMBL1964018/chembl-x-0.npy', 'chembl-GI50-CHEMBL1964021/chembl-x-0.npy', 'chembl-GI50-CHEMBL1964025/chembl-x-0.npy', 'chembl-GI50-CHEMBL1964030/chembl-x-0.npy', 'chembl-GI50-CHEMBL1964034/chembl-x-0.npy', 'chembl-GI50-CHEMBL1964037/chembl-x-0.npy', 'chembl-GI50-CHEMBL1964040/chembl-x-0.npy', 'chembl-GI50-CHEMBL1964043/chembl-x-0.npy', 'chembl-GI50-CHEMBL1964045/chembl-x-0.npy', 'chembl-GI50-CHEMBL1964047/chembl-x-0.npy', 'chembl-GI50-CHEMBL1964048/chembl-x-0.npy', 'chembl-GI50-CHEMBL1964049/chembl-x-0.npy', 'chembl-GI50-CHEMBL1964059/chembl-x-0.npy', 'chembl-GI50-CHEMBL1964063/chembl-x-0.npy', 'chembl-GI50-CHEMBL1964065/chembl-x-0.npy', 'chembl-GI50-CHEMBL1964066/chembl-x-0.npy', 'chembl-GI50-CHEMBL1964072/chembl-x-0.npy', 'chembl-GI50-CHEMBL1964075/chembl-x-0.npy', 'chembl-GI50-CHEMBL1964077/chembl-x-0.npy', 'chembl-GI50-CHEMBL1964085/chembl-x-0.npy', 'chembl-GI50-CHEMBL1964087/chembl-x-0.npy', 'chembl-GI50-CHEMBL1964088/chembl-x-0.npy', 'chembl-GI50-CHEMBL1964091/chembl-x-0.npy', 'chembl-GI50-CHEMBL1964092/chembl-x-0.npy', 'chembl-GI50-CHEMBL1964099/chembl-x-0.npy', 'chembl-INHIBITION-CHEMBL4513217/chembl-x-0.npy', 'chembl-INHIBITION-CHEMBL4513218/chembl-x-0.npy', 'chembl-INHIBITION-CHEMBL4513219/chembl-x-0.npy', 'chembl-INHIBITION-CHEMBL4513220/chembl-x-0.npy', 'chembl-INHIBITION-CHEMBL4513221/chembl-x-0.npy', 'chembl-Inhibition-CHEMBL3507681/chembl-x-0.npy', 'chembl-Inhibition-CHEMBL3988443/chembl-x-0.npy', 'chembl-Inhibition-CHEMBL4296187/chembl-x-0.npy', 'chembl-Inhibition-CHEMBL4296188/chembl-x-0.npy', 'chembl-Potency-CHEMBL1613769/chembl-x-0.npy', 'chembl-Potency-CHEMBL1613836/chembl-x-0.npy', 'chembl-Potency-CHEMBL1613838/chembl-x-0.npy', 'chembl-Potency-CHEMBL1613842/chembl-x-0.npy', 'chembl-Potency-CHEMBL1613914/chembl-x-0.npy', 'chembl-Potency-CHEMBL1614038/chembl-x-0.npy', 'chembl-Potency-CHEMBL1614079/chembl-x-0.npy', 'chembl-Potency-CHEMBL1614087/chembl-x-0.npy', 'chembl-Potency-CHEMBL1614146/chembl-x-0.npy', 'chembl-Potency-CHEMBL1614161/chembl-x-0.npy', 'chembl-Potency-CHEMBL1614166/chembl-x-0.npy', 'chembl-Potency-CHEMBL1614174/chembl-x-0.npy', 'chembl-Potency-CHEMBL1614211/chembl-x-0.npy', 'chembl-Potency-CHEMBL1614236/chembl-x-0.npy', 'chembl-Potency-CHEMBL1614249/chembl-x-0.npy', 'chembl-Potency-CHEMBL1614250/chembl-x-0.npy', 'chembl-Potency-CHEMBL1614257/chembl-x-0.npy', 'chembl-Potency-CHEMBL1614421/chembl-x-0.npy', 'chembl-Potency-CHEMBL1614441/chembl-x-0.npy', 'chembl-Potency-CHEMBL1614458/chembl-x-0.npy', 'chembl-Potency-CHEMBL1614459/chembl-x-0.npy', 'chembl-Potency-CHEMBL1614502/chembl-x-0.npy', 'chembl-Potency-CHEMBL1614530/chembl-x-0.npy', 'chembl-Potency-CHEMBL1614544/chembl-x-0.npy', 'chembl-Potency-CHEMBL1737902/chembl-x-0.npy', 'chembl-Potency-CHEMBL1737991/chembl-x-0.npy', 'chembl-Potency-CHEMBL1738132/chembl-x-0.npy', 'chembl-Potency-CHEMBL1738184/chembl-x-0.npy', 'chembl-Potency-CHEMBL1738312/chembl-x-0.npy', 'chembl-Potency-CHEMBL1738317/chembl-x-0.npy', 'chembl-Potency-CHEMBL1738442/chembl-x-0.npy', 'chembl-Potency-CHEMBL1738588/chembl-x-0.npy', 'chembl-Potency-CHEMBL1794308/chembl-x-0.npy', 'chembl-Potency-CHEMBL1794311/chembl-x-0.npy', 'chembl-Potency-CHEMBL1794345/chembl-x-0.npy', 'chembl-Potency-CHEMBL1794352/chembl-x-0.npy', 'chembl-Potency-CHEMBL1794359/chembl-x-0.npy', 'chembl-Potency-CHEMBL1794375/chembl-x-0.npy', 'chembl-Potency-CHEMBL1794401/chembl-x-0.npy', 'chembl-Potency-CHEMBL1794424/chembl-x-0.npy', 'chembl-Potency-CHEMBL1794461/chembl-x-0.npy', 'chembl-Potency-CHEMBL1794483/chembl-x-0.npy', 'chembl-Potency-CHEMBL1794553/chembl-x-0.npy', 'chembl-Potency-CHEMBL1794580/chembl-x-0.npy', 'chembl-Potency-CHEMBL1794584/chembl-x-0.npy', 'chembl-Potency-CHEMBL1794585/chembl-x-0.npy', 'chembl-Potency-CHEMBL2114713/chembl-x-0.npy', 'chembl-Potency-CHEMBL2114775/chembl-x-0.npy', 'chembl-Potency-CHEMBL2114780/chembl-x-0.npy', 'chembl-Potency-CHEMBL2114784/chembl-x-0.npy', 'chembl-Potency-CHEMBL2114788/chembl-x-0.npy', 'chembl-Potency-CHEMBL2114810/chembl-x-0.npy', 'chembl-Potency-CHEMBL2114843/chembl-x-0.npy', 'chembl-Potency-CHEMBL2114861/chembl-x-0.npy', 'chembl-Potency-CHEMBL2114913/chembl-x-0.npy', 'chembl-Potency-CHEMBL2354211/chembl-x-0.npy', 'chembl-Potency-CHEMBL2354221/chembl-x-0.npy', 'chembl-Potency-CHEMBL2354254/chembl-x-0.npy', 'chembl-Potency-CHEMBL2354287/chembl-x-0.npy', 'chembl-Potency-CHEMBL2354311/chembl-x-0.npy', 'chembl-Potency-CHEMBL3214953/chembl-x-0.npy', 'chembl-Potency-CHEMBL3215017/chembl-x-0.npy', 'chembl-Potency-CHEMBL3215106/chembl-x-0.npy', 'chembl-Potency-CHEMBL3215181/chembl-x-0.npy', 'chembl-Potency-CHEMBL3215270/chembl-x-0.npy', 'chembl-Potency-CHEMBL3215278/chembl-x-0.npy', 'chembl-Potency-CHEMBL3562077/chembl-x-0.npy', 'chembl-GI50-CHEMBL1963844/chembl-x-1.npy', 'chembl-GI50-CHEMBL1963854/chembl-x-1.npy', 'chembl-GI50-CHEMBL1963860/chembl-x-1.npy', 'chembl-GI50-CHEMBL1963866/chembl-x-1.npy', 'chembl-GI50-CHEMBL1963868/chembl-x-1.npy', 'chembl-GI50-CHEMBL1963874/chembl-x-1.npy', 'chembl-GI50-CHEMBL1963876/chembl-x-1.npy', 'chembl-GI50-CHEMBL1963880/chembl-x-1.npy', 'chembl-GI50-CHEMBL1963882/chembl-x-1.npy', 'chembl-GI50-CHEMBL1963885/chembl-x-1.npy', 'chembl-GI50-CHEMBL1963895/chembl-x-1.npy', 'chembl-GI50-CHEMBL1963900/chembl-x-1.npy', 'chembl-GI50-CHEMBL1963901/chembl-x-1.npy', 'chembl-GI50-CHEMBL1963903/chembl-x-1.npy', 'chembl-GI50-CHEMBL1963911/chembl-x-1.npy', 'chembl-GI50-CHEMBL1963921/chembl-x-1.npy', 'chembl-GI50-CHEMBL1963922/chembl-x-1.npy', 'chembl-GI50-CHEMBL1963929/chembl-x-1.npy', 'chembl-GI50-CHEMBL1963945/chembl-x-1.npy', 'chembl-GI50-CHEMBL1963953/chembl-x-1.npy', 'chembl-GI50-CHEMBL1963960/chembl-x-1.npy', 'chembl-GI50-CHEMBL1963961/chembl-x-1.npy', 'chembl-GI50-CHEMBL1963976/chembl-x-1.npy', 'chembl-GI50-CHEMBL1963981/chembl-x-1.npy', 'chembl-GI50-CHEMBL1963985/chembl-x-1.npy', 'chembl-GI50-CHEMBL1963989/chembl-x-1.npy', 'chembl-GI50-CHEMBL1963990/chembl-x-1.npy', 'chembl-GI50-CHEMBL1963991/chembl-x-1.npy', 'chembl-GI50-CHEMBL1963994/chembl-x-1.npy', 'chembl-GI50-CHEMBL1964004/chembl-x-1.npy', 'chembl-GI50-CHEMBL1964006/chembl-x-1.npy', 'chembl-GI50-CHEMBL1964007/chembl-x-1.npy', 'chembl-GI50-CHEMBL1964009/chembl-x-1.npy', 'chembl-GI50-CHEMBL1964012/chembl-x-1.npy', 'chembl-GI50-CHEMBL1964017/chembl-x-1.npy', 'chembl-GI50-CHEMBL1964018/chembl-x-1.npy', 'chembl-GI50-CHEMBL1964021/chembl-x-1.npy', 'chembl-GI50-CHEMBL1964025/chembl-x-1.npy', 'chembl-GI50-CHEMBL1964030/chembl-x-1.npy', 'chembl-GI50-CHEMBL1964034/chembl-x-1.npy', 'chembl-GI50-CHEMBL1964037/chembl-x-1.npy', 'chembl-GI50-CHEMBL1964040/chembl-x-1.npy', 'chembl-GI50-CHEMBL1964043/chembl-x-1.npy', 'chembl-GI50-CHEMBL1964045/chembl-x-1.npy', 'chembl-GI50-CHEMBL1964047/chembl-x-1.npy', 'chembl-GI50-CHEMBL1964048/chembl-x-1.npy', 'chembl-GI50-CHEMBL1964049/chembl-x-1.npy', 'chembl-GI50-CHEMBL1964059/chembl-x-1.npy', 'chembl-GI50-CHEMBL1964063/chembl-x-1.npy', 'chembl-GI50-CHEMBL1964065/chembl-x-1.npy', 'chembl-GI50-CHEMBL1964066/chembl-x-1.npy', 'chembl-GI50-CHEMBL1964072/chembl-x-1.npy', 'chembl-GI50-CHEMBL1964075/chembl-x-1.npy', 'chembl-GI50-CHEMBL1964077/chembl-x-1.npy', 'chembl-GI50-CHEMBL1964085/chembl-x-1.npy', 'chembl-GI50-CHEMBL1964087/chembl-x-1.npy', 'chembl-GI50-CHEMBL1964088/chembl-x-1.npy', 'chembl-GI50-CHEMBL1964091/chembl-x-1.npy', 'chembl-GI50-CHEMBL1964092/chembl-x-1.npy', 'chembl-GI50-CHEMBL1964099/chembl-x-1.npy', 'chembl-INHIBITION-CHEMBL4513217/chembl-x-1.npy', 'chembl-INHIBITION-CHEMBL4513218/chembl-x-1.npy', 'chembl-INHIBITION-CHEMBL4513219/chembl-x-1.npy', 'chembl-INHIBITION-CHEMBL4513220/chembl-x-1.npy', 'chembl-INHIBITION-CHEMBL4513221/chembl-x-1.npy', 'chembl-Inhibition-CHEMBL3507681/chembl-x-1.npy', 'chembl-Inhibition-CHEMBL3988443/chembl-x-1.npy', 'chembl-Inhibition-CHEMBL4296187/chembl-x-1.npy', 'chembl-Inhibition-CHEMBL4296188/chembl-x-1.npy', 'chembl-Potency-CHEMBL1613769/chembl-x-1.npy', 'chembl-Potency-CHEMBL1613836/chembl-x-1.npy', 'chembl-Potency-CHEMBL1613838/chembl-x-1.npy', 'chembl-Potency-CHEMBL1613842/chembl-x-1.npy', 'chembl-Potency-CHEMBL1613914/chembl-x-1.npy', 'chembl-Potency-CHEMBL1614038/chembl-x-1.npy', 'chembl-Potency-CHEMBL1614079/chembl-x-1.npy', 'chembl-Potency-CHEMBL1614087/chembl-x-1.npy', 'chembl-Potency-CHEMBL1614146/chembl-x-1.npy', 'chembl-Potency-CHEMBL1614161/chembl-x-1.npy', 'chembl-Potency-CHEMBL1614166/chembl-x-1.npy', 'chembl-Potency-CHEMBL1614174/chembl-x-1.npy', 'chembl-Potency-CHEMBL1614211/chembl-x-1.npy', 'chembl-Potency-CHEMBL1614236/chembl-x-1.npy', 'chembl-Potency-CHEMBL1614249/chembl-x-1.npy', 'chembl-Potency-CHEMBL1614250/chembl-x-1.npy', 'chembl-Potency-CHEMBL1614257/chembl-x-1.npy', 'chembl-Potency-CHEMBL1614421/chembl-x-1.npy', 'chembl-Potency-CHEMBL1614441/chembl-x-1.npy', 'chembl-Potency-CHEMBL1614458/chembl-x-1.npy', 'chembl-Potency-CHEMBL1614459/chembl-x-1.npy', 'chembl-Potency-CHEMBL1614502/chembl-x-1.npy', 'chembl-Potency-CHEMBL1614530/chembl-x-1.npy', 'chembl-Potency-CHEMBL1614544/chembl-x-1.npy', 'chembl-Potency-CHEMBL1737902/chembl-x-1.npy', 'chembl-Potency-CHEMBL1737991/chembl-x-1.npy', 'chembl-Potency-CHEMBL1738132/chembl-x-1.npy', 'chembl-Potency-CHEMBL1738184/chembl-x-1.npy', 'chembl-Potency-CHEMBL1738312/chembl-x-1.npy', 'chembl-Potency-CHEMBL1738317/chembl-x-1.npy', 'chembl-Potency-CHEMBL1738442/chembl-x-1.npy', 'chembl-Potency-CHEMBL1738588/chembl-x-1.npy', 'chembl-Potency-CHEMBL1794308/chembl-x-1.npy', 'chembl-Potency-CHEMBL1794311/chembl-x-1.npy', 'chembl-Potency-CHEMBL1794345/chembl-x-1.npy', 'chembl-Potency-CHEMBL1794352/chembl-x-1.npy', 'chembl-Potency-CHEMBL1794359/chembl-x-1.npy', 'chembl-Potency-CHEMBL1794375/chembl-x-1.npy', 'chembl-Potency-CHEMBL1794401/chembl-x-1.npy', 'chembl-Potency-CHEMBL1794424/chembl-x-1.npy', 'chembl-Potency-CHEMBL1794461/chembl-x-1.npy', 'chembl-Potency-CHEMBL1794483/chembl-x-1.npy', 'chembl-Potency-CHEMBL1794553/chembl-x-1.npy', 'chembl-Potency-CHEMBL1794580/chembl-x-1.npy', 'chembl-Potency-CHEMBL1794584/chembl-x-1.npy', 'chembl-Potency-CHEMBL1794585/chembl-x-1.npy', 'chembl-Potency-CHEMBL2114713/chembl-x-1.npy', 'chembl-Potency-CHEMBL2114775/chembl-x-1.npy', 'chembl-Potency-CHEMBL2114780/chembl-x-1.npy', 'chembl-Potency-CHEMBL2114784/chembl-x-1.npy', 'chembl-Potency-CHEMBL2114788/chembl-x-1.npy', 'chembl-Potency-CHEMBL2114810/chembl-x-1.npy', 'chembl-Potency-CHEMBL2114843/chembl-x-1.npy', 'chembl-Potency-CHEMBL2114861/chembl-x-1.npy', 'chembl-Potency-CHEMBL2114913/chembl-x-1.npy', 'chembl-Potency-CHEMBL2354211/chembl-x-1.npy', 'chembl-Potency-CHEMBL2354221/chembl-x-1.npy', 'chembl-Potency-CHEMBL2354254/chembl-x-1.npy', 'chembl-Potency-CHEMBL2354287/chembl-x-1.npy', 'chembl-Potency-CHEMBL2354311/chembl-x-1.npy', 'chembl-Potency-CHEMBL3214953/chembl-x-1.npy', 'chembl-Potency-CHEMBL3215017/chembl-x-1.npy', 'chembl-Potency-CHEMBL3215106/chembl-x-1.npy', 'chembl-Potency-CHEMBL3215181/chembl-x-1.npy', 'chembl-Potency-CHEMBL3215270/chembl-x-1.npy', 'chembl-Potency-CHEMBL3215278/chembl-x-1.npy', 'chembl-Potency-CHEMBL3562077/chembl-x-1.npy', 'chembl-GI50-CHEMBL1963844/chembl-x-2.npy', 'chembl-GI50-CHEMBL1963854/chembl-x-2.npy', 'chembl-GI50-CHEMBL1963860/chembl-x-2.npy', 'chembl-GI50-CHEMBL1963866/chembl-x-2.npy', 'chembl-GI50-CHEMBL1963868/chembl-x-2.npy', 'chembl-GI50-CHEMBL1963874/chembl-x-2.npy', 'chembl-GI50-CHEMBL1963876/chembl-x-2.npy', 'chembl-GI50-CHEMBL1963880/chembl-x-2.npy', 'chembl-GI50-CHEMBL1963882/chembl-x-2.npy', 'chembl-GI50-CHEMBL1963885/chembl-x-2.npy', 'chembl-GI50-CHEMBL1963895/chembl-x-2.npy', 'chembl-GI50-CHEMBL1963900/chembl-x-2.npy', 'chembl-GI50-CHEMBL1963901/chembl-x-2.npy', 'chembl-GI50-CHEMBL1963903/chembl-x-2.npy', 'chembl-GI50-CHEMBL1963911/chembl-x-2.npy', 'chembl-GI50-CHEMBL1963921/chembl-x-2.npy', 'chembl-GI50-CHEMBL1963922/chembl-x-2.npy', 'chembl-GI50-CHEMBL1963929/chembl-x-2.npy', 'chembl-GI50-CHEMBL1963945/chembl-x-2.npy', 'chembl-GI50-CHEMBL1963953/chembl-x-2.npy', 'chembl-GI50-CHEMBL1963960/chembl-x-2.npy', 'chembl-GI50-CHEMBL1963961/chembl-x-2.npy', 'chembl-GI50-CHEMBL1963976/chembl-x-2.npy', 'chembl-GI50-CHEMBL1963981/chembl-x-2.npy', 'chembl-GI50-CHEMBL1963985/chembl-x-2.npy', 'chembl-GI50-CHEMBL1963989/chembl-x-2.npy', 'chembl-GI50-CHEMBL1963990/chembl-x-2.npy', 'chembl-GI50-CHEMBL1963991/chembl-x-2.npy', 'chembl-GI50-CHEMBL1963994/chembl-x-2.npy', 'chembl-GI50-CHEMBL1964004/chembl-x-2.npy', 'chembl-GI50-CHEMBL1964006/chembl-x-2.npy', 'chembl-GI50-CHEMBL1964007/chembl-x-2.npy', 'chembl-GI50-CHEMBL1964009/chembl-x-2.npy', 'chembl-GI50-CHEMBL1964012/chembl-x-2.npy', 'chembl-GI50-CHEMBL1964017/chembl-x-2.npy', 'chembl-GI50-CHEMBL1964018/chembl-x-2.npy', 'chembl-GI50-CHEMBL1964021/chembl-x-2.npy', 'chembl-GI50-CHEMBL1964025/chembl-x-2.npy', 'chembl-GI50-CHEMBL1964030/chembl-x-2.npy', 'chembl-GI50-CHEMBL1964034/chembl-x-2.npy', 'chembl-GI50-CHEMBL1964037/chembl-x-2.npy', 'chembl-GI50-CHEMBL1964040/chembl-x-2.npy', 'chembl-GI50-CHEMBL1964043/chembl-x-2.npy', 'chembl-GI50-CHEMBL1964045/chembl-x-2.npy', 'chembl-GI50-CHEMBL1964047/chembl-x-2.npy', 'chembl-GI50-CHEMBL1964048/chembl-x-2.npy', 'chembl-GI50-CHEMBL1964049/chembl-x-2.npy', 'chembl-GI50-CHEMBL1964059/chembl-x-2.npy', 'chembl-GI50-CHEMBL1964063/chembl-x-2.npy', 'chembl-GI50-CHEMBL1964065/chembl-x-2.npy', 'chembl-GI50-CHEMBL1964066/chembl-x-2.npy', 'chembl-GI50-CHEMBL1964072/chembl-x-2.npy', 'chembl-GI50-CHEMBL1964075/chembl-x-2.npy', 'chembl-GI50-CHEMBL1964077/chembl-x-2.npy', 'chembl-GI50-CHEMBL1964085/chembl-x-2.npy', 'chembl-GI50-CHEMBL1964087/chembl-x-2.npy', 'chembl-GI50-CHEMBL1964088/chembl-x-2.npy', 'chembl-GI50-CHEMBL1964091/chembl-x-2.npy', 'chembl-GI50-CHEMBL1964092/chembl-x-2.npy', 'chembl-GI50-CHEMBL1964099/chembl-x-2.npy', 'chembl-INHIBITION-CHEMBL4513217/chembl-x-2.npy', 'chembl-INHIBITION-CHEMBL4513218/chembl-x-2.npy', 'chembl-INHIBITION-CHEMBL4513219/chembl-x-2.npy', 'chembl-INHIBITION-CHEMBL4513220/chembl-x-2.npy', 'chembl-INHIBITION-CHEMBL4513221/chembl-x-2.npy', 'chembl-Inhibition-CHEMBL3507681/chembl-x-2.npy', 'chembl-Inhibition-CHEMBL3988443/chembl-x-2.npy', 'chembl-Inhibition-CHEMBL4296187/chembl-x-2.npy', 'chembl-Inhibition-CHEMBL4296188/chembl-x-2.npy', 'chembl-Potency-CHEMBL1613769/chembl-x-2.npy', 'chembl-Potency-CHEMBL1613836/chembl-x-2.npy', 'chembl-Potency-CHEMBL1613838/chembl-x-2.npy', 'chembl-Potency-CHEMBL1613842/chembl-x-2.npy', 'chembl-Potency-CHEMBL1613914/chembl-x-2.npy', 'chembl-Potency-CHEMBL1614038/chembl-x-2.npy', 'chembl-Potency-CHEMBL1614079/chembl-x-2.npy', 'chembl-Potency-CHEMBL1614087/chembl-x-2.npy', 'chembl-Potency-CHEMBL1614146/chembl-x-2.npy', 'chembl-Potency-CHEMBL1614161/chembl-x-2.npy', 'chembl-Potency-CHEMBL1614166/chembl-x-2.npy', 'chembl-Potency-CHEMBL1614174/chembl-x-2.npy', 'chembl-Potency-CHEMBL1614211/chembl-x-2.npy', 'chembl-Potency-CHEMBL1614236/chembl-x-2.npy', 'chembl-Potency-CHEMBL1614249/chembl-x-2.npy', 'chembl-Potency-CHEMBL1614250/chembl-x-2.npy', 'chembl-Potency-CHEMBL1614257/chembl-x-2.npy', 'chembl-Potency-CHEMBL1614421/chembl-x-2.npy', 'chembl-Potency-CHEMBL1614441/chembl-x-2.npy', 'chembl-Potency-CHEMBL1614458/chembl-x-2.npy', 'chembl-Potency-CHEMBL1614459/chembl-x-2.npy', 'chembl-Potency-CHEMBL1614502/chembl-x-2.npy', 'chembl-Potency-CHEMBL1614530/chembl-x-2.npy', 'chembl-Potency-CHEMBL1614544/chembl-x-2.npy', 'chembl-Potency-CHEMBL1737902/chembl-x-2.npy', 'chembl-Potency-CHEMBL1737991/chembl-x-2.npy', 'chembl-Potency-CHEMBL1738132/chembl-x-2.npy', 'chembl-Potency-CHEMBL1738184/chembl-x-2.npy', 'chembl-Potency-CHEMBL1738312/chembl-x-2.npy', 'chembl-Potency-CHEMBL1738317/chembl-x-2.npy', 'chembl-Potency-CHEMBL1738442/chembl-x-2.npy', 'chembl-Potency-CHEMBL1738588/chembl-x-2.npy', 'chembl-Potency-CHEMBL1794308/chembl-x-2.npy', 'chembl-Potency-CHEMBL1794311/chembl-x-2.npy', 'chembl-Potency-CHEMBL1794345/chembl-x-2.npy', 'chembl-Potency-CHEMBL1794352/chembl-x-2.npy', 'chembl-Potency-CHEMBL1794359/chembl-x-2.npy', 'chembl-Potency-CHEMBL1794375/chembl-x-2.npy', 'chembl-Potency-CHEMBL1794401/chembl-x-2.npy', 'chembl-Potency-CHEMBL1794424/chembl-x-2.npy', 'chembl-Potency-CHEMBL1794461/chembl-x-2.npy', 'chembl-Potency-CHEMBL1794483/chembl-x-2.npy', 'chembl-Potency-CHEMBL1794553/chembl-x-2.npy', 'chembl-Potency-CHEMBL1794580/chembl-x-2.npy', 'chembl-Potency-CHEMBL1794584/chembl-x-2.npy', 'chembl-Potency-CHEMBL1794585/chembl-x-2.npy', 'chembl-Potency-CHEMBL2114713/chembl-x-2.npy', 'chembl-Potency-CHEMBL2114775/chembl-x-2.npy', 'chembl-Potency-CHEMBL2114780/chembl-x-2.npy', 'chembl-Potency-CHEMBL2114784/chembl-x-2.npy', 'chembl-Potency-CHEMBL2114788/chembl-x-2.npy', 'chembl-Potency-CHEMBL2114810/chembl-x-2.npy', 'chembl-Potency-CHEMBL2114843/chembl-x-2.npy', 'chembl-Potency-CHEMBL2114861/chembl-x-2.npy', 'chembl-Potency-CHEMBL2114913/chembl-x-2.npy', 'chembl-Potency-CHEMBL2354211/chembl-x-2.npy', 'chembl-Potency-CHEMBL2354221/chembl-x-2.npy', 'chembl-Potency-CHEMBL2354254/chembl-x-2.npy', 'chembl-Potency-CHEMBL2354287/chembl-x-2.npy', 'chembl-Potency-CHEMBL2354311/chembl-x-2.npy', 'chembl-Potency-CHEMBL3214953/chembl-x-2.npy', 'chembl-Potency-CHEMBL3215017/chembl-x-2.npy', 'chembl-Potency-CHEMBL3215106/chembl-x-2.npy', 'chembl-Potency-CHEMBL3215181/chembl-x-2.npy', 'chembl-Potency-CHEMBL3215270/chembl-x-2.npy', 'chembl-Potency-CHEMBL3215278/chembl-x-2.npy', 'chembl-Potency-CHEMBL3562077/chembl-x-2.npy', 'chembl-GI50-CHEMBL1963844/chembl-x-3.npy', 'chembl-GI50-CHEMBL1963854/chembl-x-3.npy', 'chembl-GI50-CHEMBL1963860/chembl-x-3.npy', 'chembl-GI50-CHEMBL1963866/chembl-x-3.npy', 'chembl-GI50-CHEMBL1963868/chembl-x-3.npy', 'chembl-GI50-CHEMBL1963874/chembl-x-3.npy', 'chembl-GI50-CHEMBL1963876/chembl-x-3.npy', 'chembl-GI50-CHEMBL1963880/chembl-x-3.npy', 'chembl-GI50-CHEMBL1963882/chembl-x-3.npy', 'chembl-GI50-CHEMBL1963885/chembl-x-3.npy', 'chembl-GI50-CHEMBL1963895/chembl-x-3.npy', 'chembl-GI50-CHEMBL1963900/chembl-x-3.npy', 'chembl-GI50-CHEMBL1963901/chembl-x-3.npy', 'chembl-GI50-CHEMBL1963903/chembl-x-3.npy', 'chembl-GI50-CHEMBL1963911/chembl-x-3.npy', 'chembl-GI50-CHEMBL1963921/chembl-x-3.npy', 'chembl-GI50-CHEMBL1963922/chembl-x-3.npy', 'chembl-GI50-CHEMBL1963929/chembl-x-3.npy', 'chembl-GI50-CHEMBL1963945/chembl-x-3.npy', 'chembl-GI50-CHEMBL1963953/chembl-x-3.npy', 'chembl-GI50-CHEMBL1963960/chembl-x-3.npy', 'chembl-GI50-CHEMBL1963961/chembl-x-3.npy', 'chembl-GI50-CHEMBL1963976/chembl-x-3.npy', 'chembl-GI50-CHEMBL1963981/chembl-x-3.npy', 'chembl-GI50-CHEMBL1963985/chembl-x-3.npy', 'chembl-GI50-CHEMBL1963989/chembl-x-3.npy', 'chembl-GI50-CHEMBL1963990/chembl-x-3.npy', 'chembl-GI50-CHEMBL1963991/chembl-x-3.npy', 'chembl-GI50-CHEMBL1963994/chembl-x-3.npy', 'chembl-GI50-CHEMBL1964004/chembl-x-3.npy', 'chembl-GI50-CHEMBL1964006/chembl-x-3.npy', 'chembl-GI50-CHEMBL1964007/chembl-x-3.npy', 'chembl-GI50-CHEMBL1964009/chembl-x-3.npy', 'chembl-GI50-CHEMBL1964012/chembl-x-3.npy', 'chembl-GI50-CHEMBL1964017/chembl-x-3.npy', 'chembl-GI50-CHEMBL1964018/chembl-x-3.npy', 'chembl-GI50-CHEMBL1964021/chembl-x-3.npy', 'chembl-GI50-CHEMBL1964025/chembl-x-3.npy', 'chembl-GI50-CHEMBL1964030/chembl-x-3.npy', 'chembl-GI50-CHEMBL1964034/chembl-x-3.npy', 'chembl-GI50-CHEMBL1964037/chembl-x-3.npy', 'chembl-GI50-CHEMBL1964040/chembl-x-3.npy', 'chembl-GI50-CHEMBL1964043/chembl-x-3.npy', 'chembl-GI50-CHEMBL1964045/chembl-x-3.npy', 'chembl-GI50-CHEMBL1964047/chembl-x-3.npy', 'chembl-GI50-CHEMBL1964048/chembl-x-3.npy', 'chembl-GI50-CHEMBL1964049/chembl-x-3.npy', 'chembl-GI50-CHEMBL1964059/chembl-x-3.npy', 'chembl-GI50-CHEMBL1964063/chembl-x-3.npy', 'chembl-GI50-CHEMBL1964065/chembl-x-3.npy', 'chembl-GI50-CHEMBL1964066/chembl-x-3.npy', 'chembl-GI50-CHEMBL1964072/chembl-x-3.npy', 'chembl-GI50-CHEMBL1964075/chembl-x-3.npy', 'chembl-GI50-CHEMBL1964077/chembl-x-3.npy', 'chembl-GI50-CHEMBL1964085/chembl-x-3.npy', 'chembl-GI50-CHEMBL1964087/chembl-x-3.npy', 'chembl-GI50-CHEMBL1964088/chembl-x-3.npy', 'chembl-GI50-CHEMBL1964091/chembl-x-3.npy', 'chembl-GI50-CHEMBL1964092/chembl-x-3.npy', 'chembl-GI50-CHEMBL1964099/chembl-x-3.npy', 'chembl-INHIBITION-CHEMBL4513217/chembl-x-3.npy', 'chembl-INHIBITION-CHEMBL4513218/chembl-x-3.npy', 'chembl-INHIBITION-CHEMBL4513219/chembl-x-3.npy', 'chembl-INHIBITION-CHEMBL4513220/chembl-x-3.npy', 'chembl-INHIBITION-CHEMBL4513221/chembl-x-3.npy', 'chembl-Inhibition-CHEMBL3507681/chembl-x-3.npy', 'chembl-Inhibition-CHEMBL3988443/chembl-x-3.npy', 'chembl-Inhibition-CHEMBL4296187/chembl-x-3.npy', 'chembl-Inhibition-CHEMBL4296188/chembl-x-3.npy', 'chembl-Potency-CHEMBL1613769/chembl-x-3.npy', 'chembl-Potency-CHEMBL1613836/chembl-x-3.npy', 'chembl-Potency-CHEMBL1613838/chembl-x-3.npy', 'chembl-Potency-CHEMBL1613842/chembl-x-3.npy', 'chembl-Potency-CHEMBL1613914/chembl-x-3.npy', 'chembl-Potency-CHEMBL1614038/chembl-x-3.npy', 'chembl-Potency-CHEMBL1614079/chembl-x-3.npy', 'chembl-Potency-CHEMBL1614087/chembl-x-3.npy', 'chembl-Potency-CHEMBL1614146/chembl-x-3.npy', 'chembl-Potency-CHEMBL1614161/chembl-x-3.npy', 'chembl-Potency-CHEMBL1614166/chembl-x-3.npy', 'chembl-Potency-CHEMBL1614174/chembl-x-3.npy', 'chembl-Potency-CHEMBL1614211/chembl-x-3.npy', 'chembl-Potency-CHEMBL1614236/chembl-x-3.npy', 'chembl-Potency-CHEMBL1614249/chembl-x-3.npy', 'chembl-Potency-CHEMBL1614250/chembl-x-3.npy', 'chembl-Potency-CHEMBL1614257/chembl-x-3.npy', 'chembl-Potency-CHEMBL1614421/chembl-x-3.npy', 'chembl-Potency-CHEMBL1614441/chembl-x-3.npy', 'chembl-Potency-CHEMBL1614458/chembl-x-3.npy', 'chembl-Potency-CHEMBL1614459/chembl-x-3.npy', 'chembl-Potency-CHEMBL1614502/chembl-x-3.npy', 'chembl-Potency-CHEMBL1614530/chembl-x-3.npy', 'chembl-Potency-CHEMBL1614544/chembl-x-3.npy', 'chembl-Potency-CHEMBL1737902/chembl-x-3.npy', 'chembl-Potency-CHEMBL1737991/chembl-x-3.npy', 'chembl-Potency-CHEMBL1738132/chembl-x-3.npy', 'chembl-Potency-CHEMBL1738184/chembl-x-3.npy', 'chembl-Potency-CHEMBL1738312/chembl-x-3.npy', 'chembl-Potency-CHEMBL1738317/chembl-x-3.npy', 'chembl-Potency-CHEMBL1738442/chembl-x-3.npy', 'chembl-Potency-CHEMBL1738588/chembl-x-3.npy', 'chembl-Potency-CHEMBL1794308/chembl-x-3.npy', 'chembl-Potency-CHEMBL1794311/chembl-x-3.npy', 'chembl-Potency-CHEMBL1794345/chembl-x-3.npy', 'chembl-Potency-CHEMBL1794352/chembl-x-3.npy', 'chembl-Potency-CHEMBL1794359/chembl-x-3.npy', 'chembl-Potency-CHEMBL1794375/chembl-x-3.npy', 'chembl-Potency-CHEMBL1794401/chembl-x-3.npy', 'chembl-Potency-CHEMBL1794424/chembl-x-3.npy', 'chembl-Potency-CHEMBL1794461/chembl-x-3.npy', 'chembl-Potency-CHEMBL1794483/chembl-x-3.npy', 'chembl-Potency-CHEMBL1794553/chembl-x-3.npy', 'chembl-Potency-CHEMBL1794580/chembl-x-3.npy', 'chembl-Potency-CHEMBL1794584/chembl-x-3.npy', 'chembl-Potency-CHEMBL1794585/chembl-x-3.npy', 'chembl-Potency-CHEMBL2114713/chembl-x-3.npy', 'chembl-Potency-CHEMBL2114775/chembl-x-3.npy', 'chembl-Potency-CHEMBL2114780/chembl-x-3.npy', 'chembl-Potency-CHEMBL2114784/chembl-x-3.npy', 'chembl-Potency-CHEMBL2114788/chembl-x-3.npy', 'chembl-Potency-CHEMBL2114810/chembl-x-3.npy', 'chembl-Potency-CHEMBL2114843/chembl-x-3.npy', 'chembl-Potency-CHEMBL2114861/chembl-x-3.npy', 'chembl-Potency-CHEMBL2114913/chembl-x-3.npy', 'chembl-Potency-CHEMBL2354211/chembl-x-3.npy', 'chembl-Potency-CHEMBL2354221/chembl-x-3.npy', 'chembl-Potency-CHEMBL2354254/chembl-x-3.npy', 'chembl-Potency-CHEMBL2354287/chembl-x-3.npy', 'chembl-Potency-CHEMBL2354311/chembl-x-3.npy', 'chembl-Potency-CHEMBL3214953/chembl-x-3.npy', 'chembl-Potency-CHEMBL3215017/chembl-x-3.npy', 'chembl-Potency-CHEMBL3215106/chembl-x-3.npy', 'chembl-Potency-CHEMBL3215181/chembl-x-3.npy', 'chembl-Potency-CHEMBL3215270/chembl-x-3.npy', 'chembl-Potency-CHEMBL3215278/chembl-x-3.npy', 'chembl-Potency-CHEMBL3562077/chembl-x-3.npy', 'chembl-GI50-CHEMBL1963844/chembl-x-4.npy', 'chembl-GI50-CHEMBL1963854/chembl-x-4.npy', 'chembl-GI50-CHEMBL1963860/chembl-x-4.npy', 'chembl-GI50-CHEMBL1963866/chembl-x-4.npy', 'chembl-GI50-CHEMBL1963868/chembl-x-4.npy', 'chembl-GI50-CHEMBL1963874/chembl-x-4.npy', 'chembl-GI50-CHEMBL1963876/chembl-x-4.npy', 'chembl-GI50-CHEMBL1963880/chembl-x-4.npy', 'chembl-GI50-CHEMBL1963882/chembl-x-4.npy', 'chembl-GI50-CHEMBL1963885/chembl-x-4.npy', 'chembl-GI50-CHEMBL1963895/chembl-x-4.npy', 'chembl-GI50-CHEMBL1963900/chembl-x-4.npy', 'chembl-GI50-CHEMBL1963901/chembl-x-4.npy', 'chembl-GI50-CHEMBL1963903/chembl-x-4.npy', 'chembl-GI50-CHEMBL1963911/chembl-x-4.npy', 'chembl-GI50-CHEMBL1963921/chembl-x-4.npy', 'chembl-GI50-CHEMBL1963922/chembl-x-4.npy', 'chembl-GI50-CHEMBL1963929/chembl-x-4.npy', 'chembl-GI50-CHEMBL1963945/chembl-x-4.npy', 'chembl-GI50-CHEMBL1963953/chembl-x-4.npy', 'chembl-GI50-CHEMBL1963960/chembl-x-4.npy', 'chembl-GI50-CHEMBL1963961/chembl-x-4.npy', 'chembl-GI50-CHEMBL1963976/chembl-x-4.npy', 'chembl-GI50-CHEMBL1963981/chembl-x-4.npy', 'chembl-GI50-CHEMBL1963985/chembl-x-4.npy', 'chembl-GI50-CHEMBL1963989/chembl-x-4.npy', 'chembl-GI50-CHEMBL1963990/chembl-x-4.npy', 'chembl-GI50-CHEMBL1963991/chembl-x-4.npy', 'chembl-GI50-CHEMBL1963994/chembl-x-4.npy', 'chembl-GI50-CHEMBL1964004/chembl-x-4.npy', 'chembl-GI50-CHEMBL1964006/chembl-x-4.npy', 'chembl-GI50-CHEMBL1964007/chembl-x-4.npy', 'chembl-GI50-CHEMBL1964009/chembl-x-4.npy', 'chembl-GI50-CHEMBL1964012/chembl-x-4.npy', 'chembl-GI50-CHEMBL1964017/chembl-x-4.npy', 'chembl-GI50-CHEMBL1964018/chembl-x-4.npy', 'chembl-GI50-CHEMBL1964021/chembl-x-4.npy', 'chembl-GI50-CHEMBL1964025/chembl-x-4.npy', 'chembl-GI50-CHEMBL1964030/chembl-x-4.npy', 'chembl-GI50-CHEMBL1964034/chembl-x-4.npy', 'chembl-GI50-CHEMBL1964037/chembl-x-4.npy', 'chembl-GI50-CHEMBL1964040/chembl-x-4.npy', 'chembl-GI50-CHEMBL1964043/chembl-x-4.npy', 'chembl-GI50-CHEMBL1964045/chembl-x-4.npy', 'chembl-GI50-CHEMBL1964047/chembl-x-4.npy', 'chembl-GI50-CHEMBL1964048/chembl-x-4.npy', 'chembl-GI50-CHEMBL1964049/chembl-x-4.npy', 'chembl-GI50-CHEMBL1964059/chembl-x-4.npy', 'chembl-GI50-CHEMBL1964063/chembl-x-4.npy', 'chembl-GI50-CHEMBL1964065/chembl-x-4.npy', 'chembl-GI50-CHEMBL1964066/chembl-x-4.npy', 'chembl-GI50-CHEMBL1964072/chembl-x-4.npy', 'chembl-GI50-CHEMBL1964075/chembl-x-4.npy', 'chembl-GI50-CHEMBL1964077/chembl-x-4.npy', 'chembl-GI50-CHEMBL1964085/chembl-x-4.npy', 'chembl-GI50-CHEMBL1964087/chembl-x-4.npy', 'chembl-GI50-CHEMBL1964088/chembl-x-4.npy', 'chembl-GI50-CHEMBL1964091/chembl-x-4.npy', 'chembl-GI50-CHEMBL1964092/chembl-x-4.npy', 'chembl-GI50-CHEMBL1964099/chembl-x-4.npy', 'chembl-INHIBITION-CHEMBL4513217/chembl-x-4.npy', 'chembl-INHIBITION-CHEMBL4513218/chembl-x-4.npy', 'chembl-INHIBITION-CHEMBL4513219/chembl-x-4.npy', 'chembl-INHIBITION-CHEMBL4513220/chembl-x-4.npy', 'chembl-INHIBITION-CHEMBL4513221/chembl-x-4.npy', 'chembl-Inhibition-CHEMBL3507681/chembl-x-4.npy', 'chembl-Inhibition-CHEMBL3988443/chembl-x-4.npy', 'chembl-Inhibition-CHEMBL4296187/chembl-x-4.npy', 'chembl-Inhibition-CHEMBL4296188/chembl-x-4.npy', 'chembl-Potency-CHEMBL1613769/chembl-x-4.npy', 'chembl-Potency-CHEMBL1613836/chembl-x-4.npy', 'chembl-Potency-CHEMBL1613838/chembl-x-4.npy', 'chembl-Potency-CHEMBL1613842/chembl-x-4.npy', 'chembl-Potency-CHEMBL1613914/chembl-x-4.npy', 'chembl-Potency-CHEMBL1614038/chembl-x-4.npy', 'chembl-Potency-CHEMBL1614079/chembl-x-4.npy', 'chembl-Potency-CHEMBL1614087/chembl-x-4.npy', 'chembl-Potency-CHEMBL1614146/chembl-x-4.npy', 'chembl-Potency-CHEMBL1614161/chembl-x-4.npy', 'chembl-Potency-CHEMBL1614166/chembl-x-4.npy', 'chembl-Potency-CHEMBL1614174/chembl-x-4.npy', 'chembl-Potency-CHEMBL1614211/chembl-x-4.npy', 'chembl-Potency-CHEMBL1614236/chembl-x-4.npy', 'chembl-Potency-CHEMBL1614249/chembl-x-4.npy', 'chembl-Potency-CHEMBL1614250/chembl-x-4.npy', 'chembl-Potency-CHEMBL1614257/chembl-x-4.npy', 'chembl-Potency-CHEMBL1614421/chembl-x-4.npy', 'chembl-Potency-CHEMBL1614441/chembl-x-4.npy', 'chembl-Potency-CHEMBL1614458/chembl-x-4.npy', 'chembl-Potency-CHEMBL1614459/chembl-x-4.npy', 'chembl-Potency-CHEMBL1614502/chembl-x-4.npy', 'chembl-Potency-CHEMBL1614530/chembl-x-4.npy', 'chembl-Potency-CHEMBL1614544/chembl-x-4.npy', 'chembl-Potency-CHEMBL1737902/chembl-x-4.npy', 'chembl-Potency-CHEMBL1737991/chembl-x-4.npy', 'chembl-Potency-CHEMBL1738132/chembl-x-4.npy', 'chembl-Potency-CHEMBL1738184/chembl-x-4.npy', 'chembl-Potency-CHEMBL1738312/chembl-x-4.npy', 'chembl-Potency-CHEMBL1738317/chembl-x-4.npy', 'chembl-Potency-CHEMBL1738442/chembl-x-4.npy', 'chembl-Potency-CHEMBL1738588/chembl-x-4.npy', 'chembl-Potency-CHEMBL1794308/chembl-x-4.npy', 'chembl-Potency-CHEMBL1794311/chembl-x-4.npy', 'chembl-Potency-CHEMBL1794345/chembl-x-4.npy', 'chembl-Potency-CHEMBL1794352/chembl-x-4.npy', 'chembl-Potency-CHEMBL1794359/chembl-x-4.npy', 'chembl-Potency-CHEMBL1794375/chembl-x-4.npy', 'chembl-Potency-CHEMBL1794401/chembl-x-4.npy', 'chembl-Potency-CHEMBL1794424/chembl-x-4.npy', 'chembl-Potency-CHEMBL1794461/chembl-x-4.npy', 'chembl-Potency-CHEMBL1794483/chembl-x-4.npy', 'chembl-Potency-CHEMBL1794553/chembl-x-4.npy', 'chembl-Potency-CHEMBL1794580/chembl-x-4.npy', 'chembl-Potency-CHEMBL1794584/chembl-x-4.npy', 'chembl-Potency-CHEMBL1794585/chembl-x-4.npy', 'chembl-Potency-CHEMBL2114713/chembl-x-4.npy', 'chembl-Potency-CHEMBL2114775/chembl-x-4.npy', 'chembl-Potency-CHEMBL2114780/chembl-x-4.npy', 'chembl-Potency-CHEMBL2114784/chembl-x-4.npy', 'chembl-Potency-CHEMBL2114788/chembl-x-4.npy', 'chembl-Potency-CHEMBL2114810/chembl-x-4.npy', 'chembl-Potency-CHEMBL2114843/chembl-x-4.npy', 'chembl-Potency-CHEMBL2114861/chembl-x-4.npy', 'chembl-Potency-CHEMBL2114913/chembl-x-4.npy', 'chembl-Potency-CHEMBL2354211/chembl-x-4.npy', 'chembl-Potency-CHEMBL2354221/chembl-x-4.npy', 'chembl-Potency-CHEMBL2354254/chembl-x-4.npy', 'chembl-Potency-CHEMBL2354287/chembl-x-4.npy', 'chembl-Potency-CHEMBL2354311/chembl-x-4.npy', 'chembl-Potency-CHEMBL3214953/chembl-x-4.npy', 'chembl-Potency-CHEMBL3215017/chembl-x-4.npy', 'chembl-Potency-CHEMBL3215106/chembl-x-4.npy', 'chembl-Potency-CHEMBL3215181/chembl-x-4.npy', 'chembl-Potency-CHEMBL3215270/chembl-x-4.npy', 'chembl-Potency-CHEMBL3215278/chembl-x-4.npy', 'chembl-Potency-CHEMBL3562077/chembl-x-4.npy', 'chembl-GI50-CHEMBL1963844/chembl-x-5.npy', 'chembl-GI50-CHEMBL1963854/chembl-x-5.npy', 'chembl-GI50-CHEMBL1963860/chembl-x-5.npy', 'chembl-GI50-CHEMBL1963866/chembl-x-5.npy', 'chembl-GI50-CHEMBL1963868/chembl-x-5.npy', 'chembl-GI50-CHEMBL1963874/chembl-x-5.npy', 'chembl-GI50-CHEMBL1963876/chembl-x-5.npy', 'chembl-GI50-CHEMBL1963880/chembl-x-5.npy', 'chembl-GI50-CHEMBL1963882/chembl-x-5.npy', 'chembl-GI50-CHEMBL1963885/chembl-x-5.npy', 'chembl-GI50-CHEMBL1963895/chembl-x-5.npy', 'chembl-GI50-CHEMBL1963900/chembl-x-5.npy', 'chembl-GI50-CHEMBL1963901/chembl-x-5.npy', 'chembl-GI50-CHEMBL1963903/chembl-x-5.npy', 'chembl-GI50-CHEMBL1963911/chembl-x-5.npy', 'chembl-GI50-CHEMBL1963921/chembl-x-5.npy', 'chembl-GI50-CHEMBL1963922/chembl-x-5.npy', 'chembl-GI50-CHEMBL1963929/chembl-x-5.npy', 'chembl-GI50-CHEMBL1963945/chembl-x-5.npy', 'chembl-GI50-CHEMBL1963953/chembl-x-5.npy', 'chembl-GI50-CHEMBL1963960/chembl-x-5.npy', 'chembl-GI50-CHEMBL1963961/chembl-x-5.npy', 'chembl-GI50-CHEMBL1963976/chembl-x-5.npy', 'chembl-GI50-CHEMBL1963981/chembl-x-5.npy', 'chembl-GI50-CHEMBL1963985/chembl-x-5.npy', 'chembl-GI50-CHEMBL1963989/chembl-x-5.npy', 'chembl-GI50-CHEMBL1963990/chembl-x-5.npy', 'chembl-GI50-CHEMBL1963991/chembl-x-5.npy', 'chembl-GI50-CHEMBL1963994/chembl-x-5.npy', 'chembl-GI50-CHEMBL1964004/chembl-x-5.npy', 'chembl-GI50-CHEMBL1964006/chembl-x-5.npy', 'chembl-GI50-CHEMBL1964007/chembl-x-5.npy', 'chembl-GI50-CHEMBL1964009/chembl-x-5.npy', 'chembl-GI50-CHEMBL1964012/chembl-x-5.npy', 'chembl-GI50-CHEMBL1964017/chembl-x-5.npy', 'chembl-GI50-CHEMBL1964018/chembl-x-5.npy', 'chembl-GI50-CHEMBL1964021/chembl-x-5.npy', 'chembl-GI50-CHEMBL1964025/chembl-x-5.npy', 'chembl-GI50-CHEMBL1964030/chembl-x-5.npy', 'chembl-GI50-CHEMBL1964034/chembl-x-5.npy', 'chembl-GI50-CHEMBL1964037/chembl-x-5.npy', 'chembl-GI50-CHEMBL1964040/chembl-x-5.npy', 'chembl-GI50-CHEMBL1964043/chembl-x-5.npy', 'chembl-GI50-CHEMBL1964045/chembl-x-5.npy', 'chembl-GI50-CHEMBL1964047/chembl-x-5.npy', 'chembl-GI50-CHEMBL1964048/chembl-x-5.npy', 'chembl-GI50-CHEMBL1964049/chembl-x-5.npy', 'chembl-GI50-CHEMBL1964059/chembl-x-5.npy', 'chembl-GI50-CHEMBL1964063/chembl-x-5.npy', 'chembl-GI50-CHEMBL1964065/chembl-x-5.npy', 'chembl-GI50-CHEMBL1964066/chembl-x-5.npy', 'chembl-GI50-CHEMBL1964072/chembl-x-5.npy', 'chembl-GI50-CHEMBL1964075/chembl-x-5.npy', 'chembl-GI50-CHEMBL1964077/chembl-x-5.npy', 'chembl-GI50-CHEMBL1964085/chembl-x-5.npy', 'chembl-GI50-CHEMBL1964087/chembl-x-5.npy', 'chembl-GI50-CHEMBL1964088/chembl-x-5.npy', 'chembl-GI50-CHEMBL1964091/chembl-x-5.npy', 'chembl-GI50-CHEMBL1964092/chembl-x-5.npy', 'chembl-GI50-CHEMBL1964099/chembl-x-5.npy', 'chembl-INHIBITION-CHEMBL4513217/chembl-x-5.npy', 'chembl-INHIBITION-CHEMBL4513218/chembl-x-5.npy', 'chembl-INHIBITION-CHEMBL4513219/chembl-x-5.npy', 'chembl-INHIBITION-CHEMBL4513220/chembl-x-5.npy', 'chembl-INHIBITION-CHEMBL4513221/chembl-x-5.npy', 'chembl-Inhibition-CHEMBL3507681/chembl-x-5.npy', 'chembl-Inhibition-CHEMBL3988443/chembl-x-5.npy', 'chembl-Potency-CHEMBL1613769/chembl-x-5.npy', 'chembl-Potency-CHEMBL1613836/chembl-x-5.npy', 'chembl-Potency-CHEMBL1613842/chembl-x-5.npy', 'chembl-Potency-CHEMBL1613914/chembl-x-5.npy', 'chembl-Potency-CHEMBL1614087/chembl-x-5.npy', 'chembl-Potency-CHEMBL1614146/chembl-x-5.npy', 'chembl-Potency-CHEMBL1614161/chembl-x-5.npy', 'chembl-Potency-CHEMBL1614166/chembl-x-5.npy', 'chembl-Potency-CHEMBL1614211/chembl-x-5.npy', 'chembl-Potency-CHEMBL1614236/chembl-x-5.npy', 'chembl-Potency-CHEMBL1614249/chembl-x-5.npy', 'chembl-Potency-CHEMBL1614257/chembl-x-5.npy', 'chembl-Potency-CHEMBL1614421/chembl-x-5.npy', 'chembl-Potency-CHEMBL1614441/chembl-x-5.npy', 'chembl-Potency-CHEMBL1614458/chembl-x-5.npy', 'chembl-Potency-CHEMBL1614459/chembl-x-5.npy', 'chembl-Potency-CHEMBL1614530/chembl-x-5.npy', 'chembl-Potency-CHEMBL1614544/chembl-x-5.npy', 'chembl-Potency-CHEMBL1737902/chembl-x-5.npy', 'chembl-Potency-CHEMBL1737991/chembl-x-5.npy', 'chembl-Potency-CHEMBL1738184/chembl-x-5.npy', 'chembl-Potency-CHEMBL1738312/chembl-x-5.npy', 'chembl-Potency-CHEMBL1738442/chembl-x-5.npy', 'chembl-Potency-CHEMBL1738588/chembl-x-5.npy', 'chembl-Potency-CHEMBL1794308/chembl-x-5.npy', 'chembl-Potency-CHEMBL1794345/chembl-x-5.npy', 'chembl-Potency-CHEMBL1794352/chembl-x-5.npy', 'chembl-Potency-CHEMBL1794359/chembl-x-5.npy', 'chembl-Potency-CHEMBL1794375/chembl-x-5.npy', 'chembl-Potency-CHEMBL1794401/chembl-x-5.npy', 'chembl-Potency-CHEMBL1794424/chembl-x-5.npy', 'chembl-Potency-CHEMBL1794483/chembl-x-5.npy', 'chembl-Potency-CHEMBL1794553/chembl-x-5.npy', 'chembl-Potency-CHEMBL1794580/chembl-x-5.npy', 'chembl-Potency-CHEMBL1794584/chembl-x-5.npy', 'chembl-Potency-CHEMBL1794585/chembl-x-5.npy', 'chembl-Potency-CHEMBL2114775/chembl-x-5.npy', 'chembl-Potency-CHEMBL2114780/chembl-x-5.npy', 'chembl-Potency-CHEMBL2114784/chembl-x-5.npy', 'chembl-Potency-CHEMBL2114788/chembl-x-5.npy', 'chembl-Potency-CHEMBL2114810/chembl-x-5.npy', 'chembl-Potency-CHEMBL2114843/chembl-x-5.npy', 'chembl-Potency-CHEMBL2114861/chembl-x-5.npy', 'chembl-Potency-CHEMBL2114913/chembl-x-5.npy', 'chembl-Potency-CHEMBL2354211/chembl-x-5.npy', 'chembl-Potency-CHEMBL2354221/chembl-x-5.npy', 'chembl-Potency-CHEMBL2354254/chembl-x-5.npy', 'chembl-Potency-CHEMBL2354287/chembl-x-5.npy', 'chembl-Potency-CHEMBL2354311/chembl-x-5.npy', 'chembl-Potency-CHEMBL3215017/chembl-x-5.npy', 'chembl-Potency-CHEMBL3215106/chembl-x-5.npy', 'chembl-Potency-CHEMBL3215181/chembl-x-5.npy', 'chembl-Potency-CHEMBL3562077/chembl-x-5.npy', 'chembl-GI50-CHEMBL1963844/chembl-x-6.npy', 'chembl-GI50-CHEMBL1963854/chembl-x-6.npy', 'chembl-GI50-CHEMBL1963860/chembl-x-6.npy', 'chembl-GI50-CHEMBL1963866/chembl-x-6.npy', 'chembl-GI50-CHEMBL1963868/chembl-x-6.npy', 'chembl-GI50-CHEMBL1963874/chembl-x-6.npy', 'chembl-GI50-CHEMBL1963876/chembl-x-6.npy', 'chembl-GI50-CHEMBL1963880/chembl-x-6.npy', 'chembl-GI50-CHEMBL1963895/chembl-x-6.npy', 'chembl-GI50-CHEMBL1963901/chembl-x-6.npy', 'chembl-GI50-CHEMBL1963903/chembl-x-6.npy', 'chembl-GI50-CHEMBL1963911/chembl-x-6.npy', 'chembl-GI50-CHEMBL1963922/chembl-x-6.npy', 'chembl-GI50-CHEMBL1963929/chembl-x-6.npy', 'chembl-GI50-CHEMBL1963953/chembl-x-6.npy', 'chembl-GI50-CHEMBL1963960/chembl-x-6.npy', 'chembl-GI50-CHEMBL1963961/chembl-x-6.npy', 'chembl-GI50-CHEMBL1963981/chembl-x-6.npy', 'chembl-GI50-CHEMBL1963985/chembl-x-6.npy', 'chembl-GI50-CHEMBL1963989/chembl-x-6.npy', 'chembl-GI50-CHEMBL1963990/chembl-x-6.npy', 'chembl-GI50-CHEMBL1963991/chembl-x-6.npy', 'chembl-GI50-CHEMBL1963994/chembl-x-6.npy', 'chembl-GI50-CHEMBL1964004/chembl-x-6.npy', 'chembl-GI50-CHEMBL1964006/chembl-x-6.npy', 'chembl-GI50-CHEMBL1964007/chembl-x-6.npy', 'chembl-GI50-CHEMBL1964009/chembl-x-6.npy', 'chembl-GI50-CHEMBL1964012/chembl-x-6.npy', 'chembl-GI50-CHEMBL1964018/chembl-x-6.npy', 'chembl-GI50-CHEMBL1964021/chembl-x-6.npy', 'chembl-GI50-CHEMBL1964025/chembl-x-6.npy', 'chembl-GI50-CHEMBL1964030/chembl-x-6.npy', 'chembl-GI50-CHEMBL1964034/chembl-x-6.npy', 'chembl-GI50-CHEMBL1964037/chembl-x-6.npy', 'chembl-GI50-CHEMBL1964040/chembl-x-6.npy', 'chembl-GI50-CHEMBL1964043/chembl-x-6.npy', 'chembl-GI50-CHEMBL1964047/chembl-x-6.npy', 'chembl-GI50-CHEMBL1964048/chembl-x-6.npy', 'chembl-GI50-CHEMBL1964049/chembl-x-6.npy', 'chembl-GI50-CHEMBL1964059/chembl-x-6.npy', 'chembl-GI50-CHEMBL1964065/chembl-x-6.npy', 'chembl-GI50-CHEMBL1964066/chembl-x-6.npy', 'chembl-GI50-CHEMBL1964072/chembl-x-6.npy', 'chembl-GI50-CHEMBL1964075/chembl-x-6.npy', 'chembl-GI50-CHEMBL1964077/chembl-x-6.npy', 'chembl-GI50-CHEMBL1964085/chembl-x-6.npy', 'chembl-GI50-CHEMBL1964087/chembl-x-6.npy', 'chembl-GI50-CHEMBL1964088/chembl-x-6.npy', 'chembl-GI50-CHEMBL1964091/chembl-x-6.npy', 'chembl-GI50-CHEMBL1964092/chembl-x-6.npy', 'chembl-INHIBITION-CHEMBL4513217/chembl-x-6.npy', 'chembl-INHIBITION-CHEMBL4513218/chembl-x-6.npy', 'chembl-INHIBITION-CHEMBL4513219/chembl-x-6.npy', 'chembl-INHIBITION-CHEMBL4513220/chembl-x-6.npy', 'chembl-INHIBITION-CHEMBL4513221/chembl-x-6.npy', 'chembl-Inhibition-CHEMBL3507681/chembl-x-6.npy', 'chembl-Inhibition-CHEMBL3988443/chembl-x-6.npy', 'chembl-Potency-CHEMBL1613836/chembl-x-6.npy', 'chembl-Potency-CHEMBL1613842/chembl-x-6.npy', 'chembl-Potency-CHEMBL1613914/chembl-x-6.npy', 'chembl-Potency-CHEMBL1614087/chembl-x-6.npy', 'chembl-Potency-CHEMBL1614146/chembl-x-6.npy', 'chembl-Potency-CHEMBL1614166/chembl-x-6.npy', 'chembl-Potency-CHEMBL1614211/chembl-x-6.npy', 'chembl-Potency-CHEMBL1614236/chembl-x-6.npy', 'chembl-Potency-CHEMBL1614249/chembl-x-6.npy', 'chembl-Potency-CHEMBL1614257/chembl-x-6.npy', 'chembl-Potency-CHEMBL1614421/chembl-x-6.npy', 'chembl-Potency-CHEMBL1614441/chembl-x-6.npy', 'chembl-Potency-CHEMBL1614458/chembl-x-6.npy', 'chembl-Potency-CHEMBL1614459/chembl-x-6.npy', 'chembl-Potency-CHEMBL1614530/chembl-x-6.npy', 'chembl-Potency-CHEMBL1614544/chembl-x-6.npy', 'chembl-Potency-CHEMBL1737902/chembl-x-6.npy', 'chembl-Potency-CHEMBL1737991/chembl-x-6.npy', 'chembl-Potency-CHEMBL1738184/chembl-x-6.npy', 'chembl-Potency-CHEMBL1738312/chembl-x-6.npy', 'chembl-Potency-CHEMBL1738442/chembl-x-6.npy', 'chembl-Potency-CHEMBL1738588/chembl-x-6.npy', 'chembl-Potency-CHEMBL1794308/chembl-x-6.npy', 'chembl-Potency-CHEMBL1794345/chembl-x-6.npy', 'chembl-Potency-CHEMBL1794352/chembl-x-6.npy', 'chembl-Potency-CHEMBL1794375/chembl-x-6.npy', 'chembl-Potency-CHEMBL1794401/chembl-x-6.npy', 'chembl-Potency-CHEMBL1794424/chembl-x-6.npy', 'chembl-Potency-CHEMBL1794483/chembl-x-6.npy', 'chembl-Potency-CHEMBL1794553/chembl-x-6.npy', 'chembl-Potency-CHEMBL1794580/chembl-x-6.npy', 'chembl-Potency-CHEMBL1794584/chembl-x-6.npy', 'chembl-Potency-CHEMBL1794585/chembl-x-6.npy', 'chembl-Potency-CHEMBL2114775/chembl-x-6.npy', 'chembl-Potency-CHEMBL2114780/chembl-x-6.npy', 'chembl-Potency-CHEMBL2114784/chembl-x-6.npy', 'chembl-Potency-CHEMBL2114788/chembl-x-6.npy', 'chembl-Potency-CHEMBL2114810/chembl-x-6.npy', 'chembl-Potency-CHEMBL2114843/chembl-x-6.npy', 'chembl-Potency-CHEMBL2354211/chembl-x-6.npy', 'chembl-Potency-CHEMBL2354221/chembl-x-6.npy', 'chembl-Potency-CHEMBL2354254/chembl-x-6.npy', 'chembl-Potency-CHEMBL2354287/chembl-x-6.npy', 'chembl-Potency-CHEMBL2354311/chembl-x-6.npy', 'chembl-Potency-CHEMBL3215106/chembl-x-6.npy', 'chembl-Potency-CHEMBL3215181/chembl-x-6.npy', 'chembl-Potency-CHEMBL3562077/chembl-x-6.npy', 'chembl-GI50-CHEMBL1963844/chembl-x-7.npy', 'chembl-GI50-CHEMBL1963854/chembl-x-7.npy', 'chembl-GI50-CHEMBL1963860/chembl-x-7.npy', 'chembl-GI50-CHEMBL1963866/chembl-x-7.npy', 'chembl-GI50-CHEMBL1963868/chembl-x-7.npy', 'chembl-GI50-CHEMBL1963874/chembl-x-7.npy', 'chembl-GI50-CHEMBL1963876/chembl-x-7.npy', 'chembl-GI50-CHEMBL1963880/chembl-x-7.npy', 'chembl-GI50-CHEMBL1963895/chembl-x-7.npy', 'chembl-GI50-CHEMBL1963901/chembl-x-7.npy', 'chembl-GI50-CHEMBL1963903/chembl-x-7.npy', 'chembl-GI50-CHEMBL1963911/chembl-x-7.npy', 'chembl-GI50-CHEMBL1963922/chembl-x-7.npy', 'chembl-GI50-CHEMBL1963929/chembl-x-7.npy', 'chembl-GI50-CHEMBL1963953/chembl-x-7.npy', 'chembl-GI50-CHEMBL1963960/chembl-x-7.npy', 'chembl-GI50-CHEMBL1963961/chembl-x-7.npy', 'chembl-GI50-CHEMBL1963981/chembl-x-7.npy', 'chembl-GI50-CHEMBL1963985/chembl-x-7.npy', 'chembl-GI50-CHEMBL1963989/chembl-x-7.npy', 'chembl-GI50-CHEMBL1963990/chembl-x-7.npy', 'chembl-GI50-CHEMBL1963991/chembl-x-7.npy', 'chembl-GI50-CHEMBL1963994/chembl-x-7.npy', 'chembl-GI50-CHEMBL1964004/chembl-x-7.npy', 'chembl-GI50-CHEMBL1964006/chembl-x-7.npy', 'chembl-GI50-CHEMBL1964007/chembl-x-7.npy', 'chembl-GI50-CHEMBL1964009/chembl-x-7.npy', 'chembl-GI50-CHEMBL1964012/chembl-x-7.npy', 'chembl-GI50-CHEMBL1964018/chembl-x-7.npy', 'chembl-GI50-CHEMBL1964021/chembl-x-7.npy', 'chembl-GI50-CHEMBL1964025/chembl-x-7.npy', 'chembl-GI50-CHEMBL1964030/chembl-x-7.npy', 'chembl-GI50-CHEMBL1964037/chembl-x-7.npy', 'chembl-GI50-CHEMBL1964040/chembl-x-7.npy', 'chembl-GI50-CHEMBL1964043/chembl-x-7.npy', 'chembl-GI50-CHEMBL1964047/chembl-x-7.npy', 'chembl-GI50-CHEMBL1964048/chembl-x-7.npy', 'chembl-GI50-CHEMBL1964049/chembl-x-7.npy', 'chembl-GI50-CHEMBL1964059/chembl-x-7.npy', 'chembl-GI50-CHEMBL1964066/chembl-x-7.npy', 'chembl-GI50-CHEMBL1964072/chembl-x-7.npy', 'chembl-GI50-CHEMBL1964075/chembl-x-7.npy', 'chembl-GI50-CHEMBL1964077/chembl-x-7.npy', 'chembl-GI50-CHEMBL1964085/chembl-x-7.npy', 'chembl-GI50-CHEMBL1964087/chembl-x-7.npy', 'chembl-GI50-CHEMBL1964088/chembl-x-7.npy', 'chembl-GI50-CHEMBL1964091/chembl-x-7.npy', 'chembl-GI50-CHEMBL1964092/chembl-x-7.npy', 'chembl-INHIBITION-CHEMBL4513217/chembl-x-7.npy', 'chembl-INHIBITION-CHEMBL4513218/chembl-x-7.npy', 'chembl-INHIBITION-CHEMBL4513219/chembl-x-7.npy', 'chembl-INHIBITION-CHEMBL4513220/chembl-x-7.npy', 'chembl-INHIBITION-CHEMBL4513221/chembl-x-7.npy', 'chembl-Inhibition-CHEMBL3507681/chembl-x-7.npy', 'chembl-Inhibition-CHEMBL3988443/chembl-x-7.npy', 'chembl-Potency-CHEMBL1613914/chembl-x-7.npy', 'chembl-Potency-CHEMBL1614087/chembl-x-7.npy', 'chembl-Potency-CHEMBL1614211/chembl-x-7.npy', 'chembl-Potency-CHEMBL1614249/chembl-x-7.npy', 'chembl-Potency-CHEMBL1614257/chembl-x-7.npy', 'chembl-Potency-CHEMBL1614421/chembl-x-7.npy', 'chembl-Potency-CHEMBL1614441/chembl-x-7.npy', 'chembl-Potency-CHEMBL1614458/chembl-x-7.npy', 'chembl-Potency-CHEMBL1614459/chembl-x-7.npy', 'chembl-Potency-CHEMBL1614530/chembl-x-7.npy', 'chembl-Potency-CHEMBL1614544/chembl-x-7.npy', 'chembl-Potency-CHEMBL1737902/chembl-x-7.npy', 'chembl-Potency-CHEMBL1737991/chembl-x-7.npy', 'chembl-Potency-CHEMBL1738184/chembl-x-7.npy', 'chembl-Potency-CHEMBL1738312/chembl-x-7.npy', 'chembl-Potency-CHEMBL1738442/chembl-x-7.npy', 'chembl-Potency-CHEMBL1738588/chembl-x-7.npy', 'chembl-Potency-CHEMBL1794308/chembl-x-7.npy', 'chembl-Potency-CHEMBL1794345/chembl-x-7.npy', 'chembl-Potency-CHEMBL1794352/chembl-x-7.npy', 'chembl-Potency-CHEMBL1794375/chembl-x-7.npy', 'chembl-Potency-CHEMBL1794401/chembl-x-7.npy', 'chembl-Potency-CHEMBL1794483/chembl-x-7.npy', 'chembl-Potency-CHEMBL1794553/chembl-x-7.npy', 'chembl-Potency-CHEMBL1794580/chembl-x-7.npy', 'chembl-Potency-CHEMBL1794584/chembl-x-7.npy', 'chembl-Potency-CHEMBL1794585/chembl-x-7.npy', 'chembl-Potency-CHEMBL2114775/chembl-x-7.npy', 'chembl-Potency-CHEMBL2114780/chembl-x-7.npy', 'chembl-Potency-CHEMBL2114784/chembl-x-7.npy', 'chembl-Potency-CHEMBL2114788/chembl-x-7.npy', 'chembl-Potency-CHEMBL2114810/chembl-x-7.npy', 'chembl-Potency-CHEMBL2114843/chembl-x-7.npy', 'chembl-Potency-CHEMBL2354211/chembl-x-7.npy', 'chembl-Potency-CHEMBL2354221/chembl-x-7.npy', 'chembl-Potency-CHEMBL2354254/chembl-x-7.npy', 'chembl-Potency-CHEMBL2354287/chembl-x-7.npy', 'chembl-Potency-CHEMBL3215106/chembl-x-7.npy', 'chembl-Potency-CHEMBL3215181/chembl-x-7.npy', 'chembl-Potency-CHEMBL3562077/chembl-x-7.npy', 'chembl-GI50-CHEMBL1963854/chembl-x-8.npy', 'chembl-GI50-CHEMBL1963868/chembl-x-8.npy', 'chembl-GI50-CHEMBL1963874/chembl-x-8.npy', 'chembl-GI50-CHEMBL1963876/chembl-x-8.npy', 'chembl-GI50-CHEMBL1963922/chembl-x-8.npy', 'chembl-GI50-CHEMBL1963929/chembl-x-8.npy', 'chembl-GI50-CHEMBL1963960/chembl-x-8.npy', 'chembl-GI50-CHEMBL1963981/chembl-x-8.npy', 'chembl-GI50-CHEMBL1963985/chembl-x-8.npy', 'chembl-GI50-CHEMBL1964006/chembl-x-8.npy', 'chembl-GI50-CHEMBL1964012/chembl-x-8.npy', 'chembl-GI50-CHEMBL1964047/chembl-x-8.npy', 'chembl-GI50-CHEMBL1964048/chembl-x-8.npy', 'chembl-GI50-CHEMBL1964059/chembl-x-8.npy', 'chembl-GI50-CHEMBL1964072/chembl-x-8.npy', 'chembl-GI50-CHEMBL1964077/chembl-x-8.npy', 'chembl-INHIBITION-CHEMBL4513217/chembl-x-8.npy', 'chembl-INHIBITION-CHEMBL4513218/chembl-x-8.npy', 'chembl-INHIBITION-CHEMBL4513219/chembl-x-8.npy', 'chembl-INHIBITION-CHEMBL4513220/chembl-x-8.npy', 'chembl-INHIBITION-CHEMBL4513221/chembl-x-8.npy', 'chembl-Inhibition-CHEMBL3507681/chembl-x-8.npy', 'chembl-Inhibition-CHEMBL3988443/chembl-x-8.npy', 'chembl-Potency-CHEMBL1614087/chembl-x-8.npy', 'chembl-Potency-CHEMBL1614249/chembl-x-8.npy', 'chembl-Potency-CHEMBL1614421/chembl-x-8.npy', 'chembl-Potency-CHEMBL1614458/chembl-x-8.npy', 'chembl-Potency-CHEMBL1614459/chembl-x-8.npy', 'chembl-Potency-CHEMBL1614530/chembl-x-8.npy', 'chembl-Potency-CHEMBL1737902/chembl-x-8.npy', 'chembl-Potency-CHEMBL1737991/chembl-x-8.npy', 'chembl-Potency-CHEMBL1738184/chembl-x-8.npy', 'chembl-Potency-CHEMBL1738312/chembl-x-8.npy', 'chembl-Potency-CHEMBL1738442/chembl-x-8.npy', 'chembl-Potency-CHEMBL1738588/chembl-x-8.npy', 'chembl-Potency-CHEMBL1794308/chembl-x-8.npy', 'chembl-Potency-CHEMBL1794345/chembl-x-8.npy', 'chembl-Potency-CHEMBL1794352/chembl-x-8.npy', 'chembl-Potency-CHEMBL1794375/chembl-x-8.npy', 'chembl-Potency-CHEMBL1794401/chembl-x-8.npy', 'chembl-Potency-CHEMBL1794483/chembl-x-8.npy', 'chembl-Potency-CHEMBL1794553/chembl-x-8.npy', 'chembl-Potency-CHEMBL1794580/chembl-x-8.npy', 'chembl-Potency-CHEMBL1794584/chembl-x-8.npy', 'chembl-Potency-CHEMBL2114775/chembl-x-8.npy', 'chembl-Potency-CHEMBL2114780/chembl-x-8.npy', 'chembl-Potency-CHEMBL2114784/chembl-x-8.npy', 'chembl-Potency-CHEMBL2114788/chembl-x-8.npy', 'chembl-Potency-CHEMBL2114810/chembl-x-8.npy', 'chembl-Potency-CHEMBL2114843/chembl-x-8.npy', 'chembl-Potency-CHEMBL2354221/chembl-x-8.npy', 'chembl-Potency-CHEMBL2354254/chembl-x-8.npy', 'chembl-Potency-CHEMBL2354287/chembl-x-8.npy', 'chembl-Potency-CHEMBL3215106/chembl-x-8.npy', 'chembl-Potency-CHEMBL3562077/chembl-x-8.npy', 'chembl-INHIBITION-CHEMBL4513217/chembl-x-9.npy', 'chembl-INHIBITION-CHEMBL4513218/chembl-x-9.npy', 'chembl-INHIBITION-CHEMBL4513219/chembl-x-9.npy', 'chembl-INHIBITION-CHEMBL4513220/chembl-x-9.npy', 'chembl-INHIBITION-CHEMBL4513221/chembl-x-9.npy', 'chembl-Inhibition-CHEMBL3507681/chembl-x-9.npy', 'chembl-Inhibition-CHEMBL3988443/chembl-x-9.npy', 'chembl-Potency-CHEMBL1614087/chembl-x-9.npy', 'chembl-Potency-CHEMBL1614421/chembl-x-9.npy', 'chembl-Potency-CHEMBL1614458/chembl-x-9.npy', 'chembl-Potency-CHEMBL1614459/chembl-x-9.npy', 'chembl-Potency-CHEMBL1614530/chembl-x-9.npy', 'chembl-Potency-CHEMBL1737902/chembl-x-9.npy', 'chembl-Potency-CHEMBL1737991/chembl-x-9.npy', 'chembl-Potency-CHEMBL1738184/chembl-x-9.npy', 'chembl-Potency-CHEMBL1738312/chembl-x-9.npy', 'chembl-Potency-CHEMBL1738442/chembl-x-9.npy', 'chembl-Potency-CHEMBL1738588/chembl-x-9.npy', 'chembl-Potency-CHEMBL1794308/chembl-x-9.npy', 'chembl-Potency-CHEMBL1794345/chembl-x-9.npy', 'chembl-Potency-CHEMBL1794352/chembl-x-9.npy', 'chembl-Potency-CHEMBL1794375/chembl-x-9.npy', 'chembl-Potency-CHEMBL1794401/chembl-x-9.npy', 'chembl-Potency-CHEMBL1794483/chembl-x-9.npy', 'chembl-Potency-CHEMBL1794553/chembl-x-9.npy', 'chembl-Potency-CHEMBL1794580/chembl-x-9.npy', 'chembl-Potency-CHEMBL1794584/chembl-x-9.npy', 'chembl-Potency-CHEMBL2114775/chembl-x-9.npy', 'chembl-Potency-CHEMBL2114780/chembl-x-9.npy', 'chembl-Potency-CHEMBL2114784/chembl-x-9.npy', 'chembl-Potency-CHEMBL2114788/chembl-x-9.npy', 'chembl-Potency-CHEMBL2114810/chembl-x-9.npy', 'chembl-Potency-CHEMBL2114843/chembl-x-9.npy', 'chembl-Potency-CHEMBL2354221/chembl-x-9.npy', 'chembl-Potency-CHEMBL2354254/chembl-x-9.npy', 'chembl-Potency-CHEMBL3215106/chembl-x-9.npy', 'chembl-Potency-CHEMBL3562077/chembl-x-9.npy', 'chembl-INHIBITION-CHEMBL4513217/chembl-x-10.npy', 'chembl-INHIBITION-CHEMBL4513218/chembl-x-10.npy', 'chembl-INHIBITION-CHEMBL4513219/chembl-x-10.npy', 'chembl-INHIBITION-CHEMBL4513220/chembl-x-10.npy', 'chembl-INHIBITION-CHEMBL4513221/chembl-x-10.npy', 'chembl-Inhibition-CHEMBL3507681/chembl-x-10.npy', 'chembl-Inhibition-CHEMBL3988443/chembl-x-10.npy', 'chembl-Potency-CHEMBL1614087/chembl-x-10.npy', 'chembl-Potency-CHEMBL1614458/chembl-x-10.npy', 'chembl-Potency-CHEMBL1614459/chembl-x-10.npy', 'chembl-Potency-CHEMBL1614530/chembl-x-10.npy', 'chembl-Potency-CHEMBL1737902/chembl-x-10.npy', 'chembl-Potency-CHEMBL1737991/chembl-x-10.npy', 'chembl-Potency-CHEMBL1738184/chembl-x-10.npy', 'chembl-Potency-CHEMBL1738312/chembl-x-10.npy', 'chembl-Potency-CHEMBL1738442/chembl-x-10.npy', 'chembl-Potency-CHEMBL1738588/chembl-x-10.npy', 'chembl-Potency-CHEMBL1794308/chembl-x-10.npy', 'chembl-Potency-CHEMBL1794345/chembl-x-10.npy', 'chembl-Potency-CHEMBL1794352/chembl-x-10.npy', 'chembl-Potency-CHEMBL1794375/chembl-x-10.npy', 'chembl-Potency-CHEMBL1794401/chembl-x-10.npy', 'chembl-Potency-CHEMBL1794483/chembl-x-10.npy', 'chembl-Potency-CHEMBL1794553/chembl-x-10.npy', 'chembl-Potency-CHEMBL1794580/chembl-x-10.npy', 'chembl-Potency-CHEMBL1794584/chembl-x-10.npy', 'chembl-Potency-CHEMBL2114775/chembl-x-10.npy', 'chembl-Potency-CHEMBL2114780/chembl-x-10.npy', 'chembl-Potency-CHEMBL2114784/chembl-x-10.npy', 'chembl-Potency-CHEMBL2114788/chembl-x-10.npy', 'chembl-Potency-CHEMBL2114810/chembl-x-10.npy', 'chembl-Potency-CHEMBL2114843/chembl-x-10.npy', 'chembl-Potency-CHEMBL2354221/chembl-x-10.npy', 'chembl-Potency-CHEMBL2354254/chembl-x-10.npy', 'chembl-Potency-CHEMBL3562077/chembl-x-10.npy', 'chembl-INHIBITION-CHEMBL4513217/chembl-x-11.npy', 'chembl-INHIBITION-CHEMBL4513218/chembl-x-11.npy', 'chembl-INHIBITION-CHEMBL4513219/chembl-x-11.npy', 'chembl-INHIBITION-CHEMBL4513220/chembl-x-11.npy', 'chembl-INHIBITION-CHEMBL4513221/chembl-x-11.npy', 'chembl-Inhibition-CHEMBL3507681/chembl-x-11.npy', 'chembl-Inhibition-CHEMBL3988443/chembl-x-11.npy', 'chembl-Potency-CHEMBL1614458/chembl-x-11.npy', 'chembl-Potency-CHEMBL1614459/chembl-x-11.npy', 'chembl-Potency-CHEMBL1614530/chembl-x-11.npy', 'chembl-Potency-CHEMBL1737902/chembl-x-11.npy', 'chembl-Potency-CHEMBL1738184/chembl-x-11.npy', 'chembl-Potency-CHEMBL1738312/chembl-x-11.npy', 'chembl-Potency-CHEMBL1738442/chembl-x-11.npy', 'chembl-Potency-CHEMBL1738588/chembl-x-11.npy', 'chembl-Potency-CHEMBL1794308/chembl-x-11.npy', 'chembl-Potency-CHEMBL1794345/chembl-x-11.npy', 'chembl-Potency-CHEMBL1794352/chembl-x-11.npy', 'chembl-Potency-CHEMBL1794375/chembl-x-11.npy', 'chembl-Potency-CHEMBL1794401/chembl-x-11.npy', 'chembl-Potency-CHEMBL1794483/chembl-x-11.npy', 'chembl-Potency-CHEMBL1794553/chembl-x-11.npy', 'chembl-Potency-CHEMBL1794580/chembl-x-11.npy', 'chembl-Potency-CHEMBL1794584/chembl-x-11.npy', 'chembl-Potency-CHEMBL2114775/chembl-x-11.npy', 'chembl-Potency-CHEMBL2114780/chembl-x-11.npy', 'chembl-Potency-CHEMBL2114788/chembl-x-11.npy', 'chembl-Potency-CHEMBL2114810/chembl-x-11.npy', 'chembl-Potency-CHEMBL2114843/chembl-x-11.npy', 'chembl-Potency-CHEMBL2354221/chembl-x-11.npy', 'chembl-Potency-CHEMBL2354254/chembl-x-11.npy', 'chembl-Potency-CHEMBL3562077/chembl-x-11.npy', 'chembl-INHIBITION-CHEMBL4513217/chembl-x-12.npy', 'chembl-INHIBITION-CHEMBL4513218/chembl-x-12.npy', 'chembl-INHIBITION-CHEMBL4513219/chembl-x-12.npy', 'chembl-INHIBITION-CHEMBL4513220/chembl-x-12.npy', 'chembl-INHIBITION-CHEMBL4513221/chembl-x-12.npy', 'chembl-Inhibition-CHEMBL3507681/chembl-x-12.npy', 'chembl-Inhibition-CHEMBL3988443/chembl-x-12.npy', 'chembl-Potency-CHEMBL1614458/chembl-x-12.npy', 'chembl-Potency-CHEMBL1614459/chembl-x-12.npy', 'chembl-Potency-CHEMBL1614530/chembl-x-12.npy', 'chembl-Potency-CHEMBL1737902/chembl-x-12.npy', 'chembl-Potency-CHEMBL1738184/chembl-x-12.npy', 'chembl-Potency-CHEMBL1738442/chembl-x-12.npy', 'chembl-Potency-CHEMBL1738588/chembl-x-12.npy', 'chembl-Potency-CHEMBL1794308/chembl-x-12.npy', 'chembl-Potency-CHEMBL1794345/chembl-x-12.npy', 'chembl-Potency-CHEMBL1794352/chembl-x-12.npy', 'chembl-Potency-CHEMBL1794375/chembl-x-12.npy', 'chembl-Potency-CHEMBL1794401/chembl-x-12.npy', 'chembl-Potency-CHEMBL1794483/chembl-x-12.npy', 'chembl-Potency-CHEMBL1794580/chembl-x-12.npy', 'chembl-Potency-CHEMBL1794584/chembl-x-12.npy', 'chembl-Potency-CHEMBL2114775/chembl-x-12.npy', 'chembl-Potency-CHEMBL2114788/chembl-x-12.npy', 'chembl-Potency-CHEMBL2114810/chembl-x-12.npy', 'chembl-Potency-CHEMBL2114843/chembl-x-12.npy', 'chembl-Potency-CHEMBL2354221/chembl-x-12.npy', 'chembl-Potency-CHEMBL2354254/chembl-x-12.npy', 'chembl-Potency-CHEMBL3562077/chembl-x-12.npy', 'chembl-INHIBITION-CHEMBL4513217/chembl-x-13.npy', 'chembl-INHIBITION-CHEMBL4513218/chembl-x-13.npy', 'chembl-INHIBITION-CHEMBL4513219/chembl-x-13.npy', 'chembl-INHIBITION-CHEMBL4513221/chembl-x-13.npy', 'chembl-Inhibition-CHEMBL3507681/chembl-x-13.npy', 'chembl-Inhibition-CHEMBL3988443/chembl-x-13.npy', 'chembl-Potency-CHEMBL1614458/chembl-x-13.npy', 'chembl-Potency-CHEMBL1614459/chembl-x-13.npy', 'chembl-Potency-CHEMBL1737902/chembl-x-13.npy', 'chembl-Potency-CHEMBL1738184/chembl-x-13.npy', 'chembl-Potency-CHEMBL1738442/chembl-x-13.npy', 'chembl-Potency-CHEMBL1738588/chembl-x-13.npy', 'chembl-Potency-CHEMBL1794345/chembl-x-13.npy', 'chembl-Potency-CHEMBL1794375/chembl-x-13.npy', 'chembl-Potency-CHEMBL1794401/chembl-x-13.npy', 'chembl-Potency-CHEMBL1794483/chembl-x-13.npy', 'chembl-Potency-CHEMBL1794580/chembl-x-13.npy', 'chembl-Potency-CHEMBL2114775/chembl-x-13.npy', 'chembl-Potency-CHEMBL2114788/chembl-x-13.npy', 'chembl-Potency-CHEMBL2114810/chembl-x-13.npy', 'chembl-Potency-CHEMBL2114843/chembl-x-13.npy', 'chembl-Potency-CHEMBL2354221/chembl-x-13.npy', 'chembl-Potency-CHEMBL2354254/chembl-x-13.npy', 'chembl-Potency-CHEMBL3562077/chembl-x-13.npy', 'chembl-Potency-CHEMBL1614458/chembl-x-14.npy', 'chembl-Potency-CHEMBL1614459/chembl-x-14.npy', 'chembl-Potency-CHEMBL1737902/chembl-x-14.npy', 'chembl-Potency-CHEMBL1738184/chembl-x-14.npy', 'chembl-Potency-CHEMBL1738442/chembl-x-14.npy', 'chembl-Potency-CHEMBL1738588/chembl-x-14.npy', 'chembl-Potency-CHEMBL1794345/chembl-x-14.npy', 'chembl-Potency-CHEMBL1794375/chembl-x-14.npy', 'chembl-Potency-CHEMBL1794401/chembl-x-14.npy', 'chembl-Potency-CHEMBL1794483/chembl-x-14.npy', 'chembl-Potency-CHEMBL1794580/chembl-x-14.npy', 'chembl-Potency-CHEMBL2114775/chembl-x-14.npy', 'chembl-Potency-CHEMBL2114788/chembl-x-14.npy', 'chembl-Potency-CHEMBL2114810/chembl-x-14.npy', 'chembl-Potency-CHEMBL2354221/chembl-x-14.npy', 'chembl-Potency-CHEMBL2354254/chembl-x-14.npy', 'chembl-Potency-CHEMBL1614458/chembl-x-15.npy', 'chembl-Potency-CHEMBL1614459/chembl-x-15.npy', 'chembl-Potency-CHEMBL1737902/chembl-x-15.npy', 'chembl-Potency-CHEMBL1738184/chembl-x-15.npy', 'chembl-Potency-CHEMBL1738442/chembl-x-15.npy', 'chembl-Potency-CHEMBL1738588/chembl-x-15.npy', 'chembl-Potency-CHEMBL1794345/chembl-x-15.npy', 'chembl-Potency-CHEMBL1794375/chembl-x-15.npy', 'chembl-Potency-CHEMBL1794401/chembl-x-15.npy', 'chembl-Potency-CHEMBL1794483/chembl-x-15.npy', 'chembl-Potency-CHEMBL1794580/chembl-x-15.npy', 'chembl-Potency-CHEMBL2114775/chembl-x-15.npy', 'chembl-Potency-CHEMBL2114788/chembl-x-15.npy', 'chembl-Potency-CHEMBL2114810/chembl-x-15.npy', 'chembl-Potency-CHEMBL2354221/chembl-x-15.npy', 'chembl-Potency-CHEMBL2354254/chembl-x-15.npy', 'chembl-Potency-CHEMBL1614459/chembl-x-16.npy', 'chembl-Potency-CHEMBL1738442/chembl-x-16.npy', 'chembl-Potency-CHEMBL1738588/chembl-x-16.npy', 'chembl-Potency-CHEMBL1794345/chembl-x-16.npy', 'chembl-Potency-CHEMBL1794375/chembl-x-16.npy', 'chembl-Potency-CHEMBL1794401/chembl-x-16.npy', 'chembl-Potency-CHEMBL1794483/chembl-x-16.npy', 'chembl-Potency-CHEMBL1794580/chembl-x-16.npy', 'chembl-Potency-CHEMBL2114788/chembl-x-16.npy', 'chembl-Potency-CHEMBL2114810/chembl-x-16.npy', 'chembl-Potency-CHEMBL2354221/chembl-x-16.npy', 'chembl-Potency-CHEMBL2354254/chembl-x-16.npy', 'chembl-Potency-CHEMBL1614459/chembl-x-17.npy', 'chembl-Potency-CHEMBL1738442/chembl-x-17.npy', 'chembl-Potency-CHEMBL1738588/chembl-x-17.npy', 'chembl-Potency-CHEMBL1794345/chembl-x-17.npy', 'chembl-Potency-CHEMBL1794375/chembl-x-17.npy', 'chembl-Potency-CHEMBL1794401/chembl-x-17.npy', 'chembl-Potency-CHEMBL1794483/chembl-x-17.npy', 'chembl-Potency-CHEMBL1794580/chembl-x-17.npy', 'chembl-Potency-CHEMBL2114788/chembl-x-17.npy', 'chembl-Potency-CHEMBL2114810/chembl-x-17.npy', 'chembl-Potency-CHEMBL2354221/chembl-x-17.npy', 'chembl-Potency-CHEMBL2354254/chembl-x-17.npy', 'chembl-Potency-CHEMBL1738442/chembl-x-18.npy', 'chembl-Potency-CHEMBL1738588/chembl-x-18.npy', 'chembl-Potency-CHEMBL1794345/chembl-x-18.npy', 'chembl-Potency-CHEMBL1794401/chembl-x-18.npy', 'chembl-Potency-CHEMBL1794483/chembl-x-18.npy', 'chembl-Potency-CHEMBL1794580/chembl-x-18.npy', 'chembl-Potency-CHEMBL2114788/chembl-x-18.npy', 'chembl-Potency-CHEMBL2354221/chembl-x-18.npy', 'chembl-Potency-CHEMBL2354254/chembl-x-18.npy', 'chembl-Potency-CHEMBL1794345/chembl-x-19.npy', 'chembl-Potency-CHEMBL1794483/chembl-x-19.npy', 'chembl-Potency-CHEMBL1794580/chembl-x-19.npy', 'chembl-Potency-CHEMBL2114788/chembl-x-19.npy', 'chembl-Potency-CHEMBL2354221/chembl-x-19.npy', 'chembl-Potency-CHEMBL2354254/chembl-x-19.npy', 'chembl-Potency-CHEMBL1794345/chembl-x-20.npy', 'chembl-Potency-CHEMBL1794483/chembl-x-20.npy', 'chembl-Potency-CHEMBL1794580/chembl-x-20.npy', 'chembl-Potency-CHEMBL2114788/chembl-x-20.npy', 'chembl-Potency-CHEMBL2354221/chembl-x-20.npy', 'chembl-Potency-CHEMBL2354254/chembl-x-20.npy', 'chembl-Potency-CHEMBL1794345/chembl-x-21.npy', 'chembl-Potency-CHEMBL1794483/chembl-x-21.npy', 'chembl-Potency-CHEMBL1794580/chembl-x-21.npy', 'chembl-Potency-CHEMBL2354221/chembl-x-21.npy', 'chembl-Potency-CHEMBL2354254/chembl-x-21.npy', 'chembl-Potency-CHEMBL1794345/chembl-x-22.npy', 'chembl-Potency-CHEMBL1794483/chembl-x-22.npy', 'chembl-Potency-CHEMBL1794580/chembl-x-22.npy', 'chembl-Potency-CHEMBL2354221/chembl-x-22.npy', 'chembl-Potency-CHEMBL2354254/chembl-x-22.npy', 'chembl-Potency-CHEMBL1794345/chembl-x-23.npy', 'chembl-Potency-CHEMBL1794483/chembl-x-23.npy', 'chembl-Potency-CHEMBL1794580/chembl-x-23.npy', 'chembl-Potency-CHEMBL2354221/chembl-x-23.npy', 'chembl-Potency-CHEMBL2354254/chembl-x-23.npy', 'chembl-Potency-CHEMBL1794345/chembl-x-24.npy', 'chembl-Potency-CHEMBL1794580/chembl-x-24.npy', 'chembl-Potency-CHEMBL2354221/chembl-x-24.npy', 'chembl-Potency-CHEMBL2354254/chembl-x-24.npy', 'chembl-Potency-CHEMBL1794345/chembl-x-25.npy', 'chembl-Potency-CHEMBL1794580/chembl-x-25.npy', 'chembl-Potency-CHEMBL2354221/chembl-x-25.npy', 'chembl-Potency-CHEMBL2354254/chembl-x-25.npy', 'chembl-Potency-CHEMBL1794345/chembl-x-26.npy', 'chembl-Potency-CHEMBL1794580/chembl-x-26.npy', 'chembl-Potency-CHEMBL2354221/chembl-x-26.npy', 'chembl-Potency-CHEMBL2354254/chembl-x-26.npy', 'chembl-Potency-CHEMBL1794345/chembl-x-27.npy', 'chembl-Potency-CHEMBL2354221/chembl-x-27.npy', 'chembl-Potency-CHEMBL2354254/chembl-x-27.npy', 'chembl-Potency-CHEMBL1794345/chembl-x-28.npy', 'chembl-Potency-CHEMBL2354221/chembl-x-28.npy', 'chembl-Potency-CHEMBL2354254/chembl-x-28.npy', 'chembl-Potency-CHEMBL1794345/chembl-x-29.npy', 'chembl-Potency-CHEMBL2354221/chembl-x-29.npy', 'chembl-Potency-CHEMBL2354254/chembl-x-29.npy', 'chembl-Potency-CHEMBL1794345/chembl-x-30.npy', 'chembl-Potency-CHEMBL2354221/chembl-x-30.npy', 'chembl-Potency-CHEMBL2354254/chembl-x-30.npy', 'chembl-Potency-CHEMBL1794345/chembl-x-31.npy', 'chembl-Potency-CHEMBL2354221/chembl-x-31.npy', 'chembl-Potency-CHEMBL2354254/chembl-x-31.npy', 'chembl-Potency-CHEMBL1794345/chembl-x-32.npy', 'chembl-Potency-CHEMBL2354221/chembl-x-32.npy', 'chembl-Potency-CHEMBL1794345/chembl-x-33.npy', 'chembl-Potency-CHEMBL2354221/chembl-x-33.npy', 'chembl-Potency-CHEMBL1794345/chembl-x-34.npy', 'chembl-Potency-CHEMBL2354221/chembl-x-34.npy', 'chembl-Potency-CHEMBL2354221/chembl-x-35.npy']


class ChEMBLDataset(DiscreteDataset):
    """A molecule design dataset that defines a common set of functions
    and attributes for a model-based optimization dataset, where the
    goal is to find a design 'x' that maximizes a prediction 'y':

    max_x { y = f(x) }

    Public Attributes:

    name: str
        An attribute that specifies the name of a model-based optimization
        dataset, which might be used when labelling plots in a diagram of
        performance in a research paper using design-bench
    x_name: str
        An attribute that specifies the name of designs in a model-based
        optimization dataset, which might be used when labelling plots
        in a visualization of performance in a research paper
    y_name: str
        An attribute that specifies the name of predictions in a model-based
        optimization dataset, which might be used when labelling plots
        in a visualization of performance in a research paper

    x: np.ndarray
        the design values 'x' for a model-based optimization problem
        represented as a numpy array of arbitrary type
    input_shape: Tuple[int]
        the shape of a single design values 'x', represented as a list of
        integers similar to calling np.ndarray.shape
    input_size: int
        the total number of components in the design values 'x', represented
        as a single integer, the product of its shape entries
    input_dtype: np.dtype
        the data type of the design values 'x', which is typically either
        floating point or integer (np.float32 or np.int32)

    y: np.ndarray
        the prediction values 'y' for a model-based optimization problem
        represented by a scalar floating point value per 'x'
    output_shape: Tuple[int]
        the shape of a single prediction value 'y', represented as a list of
        integers similar to calling np.ndarray.shape
    output_size: int
        the total number of components in the prediction values 'y',
        represented as a single integer, the product of its shape entries
    output_dtype: np.dtype
        the data type of the prediction values 'y', which is typically a
        type of floating point (np.float32 or np.float16)

    dataset_size: int
        the total number of paired design values 'x' and prediction values
        'y' in the dataset, represented as a single integer
    dataset_distribution: Callable[np.ndarray, np.ndarray]
        the target distribution of the model-based optimization dataset
        marginal p(y) used for controlling the sampling distribution
    dataset_max_percentile: float
        the percentile between 0 and 100 of prediction values 'y' above
        which are hidden from access by members outside the class
    dataset_min_percentile: float
        the percentile between 0 and 100 of prediction values 'y' below
        which are hidden from access by members outside the class
    dataset_max_output: float
        the specific cutoff threshold for prediction values 'y' above
        which are hidden from access by members outside the class
    dataset_min_output: float
        the specific cutoff threshold for prediction values 'y' below
        which are hidden from access by members outside the class

    internal_batch_size: int
        the integer number of samples per batch that is used internally
        when processing the dataset and generating samples
    freeze_statistics: bool
        a boolean indicator that when set to true prevents methods from
        changing the normalization and sub sampling statistics

    is_normalized_x: bool
        a boolean indicator that specifies whether the design values
        in the dataset are being normalized
    x_mean: np.ndarray
        a numpy array that is automatically calculated to be the mean
        of visible design values in the dataset
    x_standard_dev: np.ndarray
        a numpy array that is automatically calculated to be the standard
        deviation of visible design values in the dataset

    is_normalized_y: bool
        a boolean indicator that specifies whether the prediction values
        in the dataset are being normalized
    y_mean: np.ndarray
        a numpy array that is automatically calculated to be the mean
        of visible prediction values in the dataset
    y_standard_dev: np.ndarray
        a numpy array that is automatically calculated to be the standard
        deviation of visible prediction values in the dataset

    is_logits: bool (only supported for a DiscreteDataset)
        a value that indicates whether the design values contained in the
        model-based optimization dataset have already been converted to
        logits and need not be converted again

    Public Methods:

    iterate_batches(batch_size: int, return_x: bool,
                    return_y: bool, drop_remainder: bool)
                    -> Iterable[Tuple[np.ndarray, np.ndarray]]:
        Returns an object that supports iterations, which yields tuples of
        design values 'x' and prediction values 'y' from a model-based
        optimization data set for training a model
    iterate_samples(return_x: bool, return_y: bool):
                    -> Iterable[Tuple[np.ndarray, np.ndarray]]:
        Returns an object that supports iterations, which yields tuples of
        design values 'x' and prediction values 'y' from a model-based
        optimization data set for training a model

    subsample(max_samples: int,
              max_percentile: float,
              min_percentile: float):
        a function that exposes a subsampled version of a much larger
        model-based optimization dataset containing design values 'x'
        whose prediction values 'y' are skewed
    relabel(relabel_function:
            Callable[[np.ndarray, np.ndarray], np.ndarray]):
        a function that accepts a function that maps from a dataset of
        design values 'x' and prediction values y to a new set of
        prediction values 'y' and relabels the model-based optimization dataset

    clone(subset: set, shard_size: int,
          to_disk: bool, disk_target: str, is_absolute: bool):
        Generate a cloned copy of a model-based optimization dataset
        using the provided name and shard generation settings; useful
        when relabelling a dataset buffer from the dis
    split(fraction: float, subset: set, shard_size: int,
          to_disk: bool, disk_target: str, is_absolute: bool):
        split a model-based optimization data set into a training set and
        a validation set allocating 'fraction' of the data set to the
        validation set and the rest to the training set

    normalize_x(new_x: np.ndarray) -> np.ndarray:
        a helper function that accepts floating point design values 'x'
        as input and standardizes them so that they have zero
        empirical mean and unit empirical variance
    denormalize_x(new_x: np.ndarray) -> np.ndarray:
        a helper function that accepts floating point design values 'x'
        as input and undoes standardization so that they have their
        original empirical mean and variance
    normalize_y(new_x: np.ndarray) -> np.ndarray:
        a helper function that accepts floating point prediction values 'y'
        as input and standardizes them so that they have zero
        empirical mean and unit empirical variance
    denormalize_y(new_x: np.ndarray) -> np.ndarray:
        a helper function that accepts floating point prediction values 'y'
        as input and undoes standardization so that they have their
        original empirical mean and variance

    map_normalize_x():
        a destructive function that standardizes the design values 'x'
        in the class dataset in-place so that they have zero empirical
        mean and unit variance
    map_denormalize_x():
        a destructive function that undoes standardization of the
        design values 'x' in the class dataset in-place which are expected
        to have zero  empirical mean and unit variance
    map_normalize_y():
        a destructive function that standardizes the prediction values 'y'
        in the class dataset in-place so that they have zero empirical
        mean and unit variance
    map_denormalize_y():
        a destructive function that undoes standardization of the
        prediction values 'y' in the class dataset in-place which are
        expected to have zero empirical mean and unit variance

    --- for discrete tasks only

    to_logits(np.ndarray) > np.ndarray:
        A helper function that accepts design values represented as a numpy
        array of integers as input and converts them to floating point
        logits of a certain probability distribution
    to_integers(np.ndarray) > np.ndarray:
        A helper function that accepts design values represented as a numpy
        array of floating point logits as input and converts them to integer
        representing the max of the distribution

    map_to_logits():
        a function that processes the dataset corresponding to this
        model-based optimization problem, and converts integers to a
        floating point representation as logits
    map_to_integers():
        a function that processes the dataset corresponding to this
        model-based optimization problem, and converts a floating point
        representation as logits to integers

    """

    name = "chembl/chembl"
    y_name = "standard_value"
    x_name = "smiles"

    @staticmethod
    def register_x_shards(assay_chembl_id="CHEMBL1964047",
                          standard_type="GI50"):  # max percentile 53 works well
        """Registers a remote file for download that contains design values
        in a format compatible with the dataset builder class;
        these files are downloaded all at once in the dataset initialization

        Arguments:

        assay_chembl_id: str
            a string identifier that specifies which assay to use for
            model-based optimization, where the goal is to find a design
            value 'x' that maximizes a certain property
        standard_type: str
            a string identifier that specifies which property of the assay
            is being measured for model-based optimization, where the goal is
            to maximize that property

        Returns:

        resources: list of RemoteResource
            a list of RemoteResource objects specific to this dataset, which
            will be automatically downloaded while the dataset is built
            and may serve as shards if the dataset is large

        """

        return [DiskResource(
            file, is_absolute=False,
            download_target=f"{SERVER_URL}/{file}",
            download_method="direct") for file in CHEMBL_FILES
            if f"{standard_type}-{assay_chembl_id}" in file]

    @staticmethod
    def register_y_shards(assay_chembl_id="CHEMBL1964047",
                          standard_type="GI50"):
        """Registers a remote file for download that contains prediction
        values in a format compatible with the dataset builder class;
        these files are downloaded all at once in the dataset initialization

        Arguments:

        assay_chembl_id: str
            a string identifier that specifies which assay to use for
            model-based optimization, where the goal is to find a design
            value 'x' that maximizes a certain property
        standard_type: str
            a string identifier that specifies which property of the assay
            is being measured for model-based optimization, where the goal is
            to maximize that property

        Returns:

        resources: list of RemoteResource
            a list of RemoteResource objects specific to this dataset, which
            will be automatically downloaded while the dataset is built
            and may serve as shards if the dataset is large

        """

        return [DiskResource(
            file.replace("-x-", "-y-"), is_absolute=False,
            download_target=f"{SERVER_URL}/{file.replace('-x-', '-y-')}",
            download_method="direct") for file in CHEMBL_FILES
            if f"{standard_type}-{assay_chembl_id}" in file]

    def __init__(self, assay_chembl_id="CHEMBL1964047",
                 standard_type="GI50",
                 soft_interpolation=0.6, **kwargs):
        """Initialize a model-based optimization dataset and prepare
        that dataset by loading that dataset from disk and modifying
        its distribution

        Arguments:

        assay_chembl_id: str
            a string identifier that specifies which assay to use for
            model-based optimization, where the goal is to find a design
            value 'x' that maximizes a certain property
        standard_type: str
            a string identifier that specifies which property of the assay
            is being measured for model-based optimization, where the goal is
            to maximize that property
        soft_interpolation: float
            a floating point hyper parameter used when converting design values
            from integers to a floating point representation as logits, which
            interpolates between a uniform and dirac distribution
            1.0 = dirac, 0.0 -> uniform
        **kwargs: dict
            additional keyword arguments which are used to parameterize the
            data set generation process, including which shard files are used
            if multiple sets of data set shard files can be loaded

        """

        # set the names the describe the dataset
        self.name = f"chembl-{standard_type}-{assay_chembl_id}/chembl"
        self.y_name = standard_type

        # initialize the dataset using the method in the base class
        super(ChEMBLDataset, self).__init__(
            self.register_x_shards(assay_chembl_id=assay_chembl_id,
                                   standard_type=standard_type),
            self.register_y_shards(assay_chembl_id=assay_chembl_id,
                                   standard_type=standard_type),
            is_logits=False, num_classes=591,
            soft_interpolation=soft_interpolation, **kwargs)
